define({ "api": [
  {
    "type": "GET",
      "url": "/v1/appinfo",
      "title": "Get Application Information",
      "name": "GET_API_1",
      "group": "AppInfo",
      "version": "1.0.0",
      "description": "<p>Retrieve all information of application from environment variables.</p>",
      "success": {
          "examples": [
              {
                  "title": "Response Example(json)",
                  "content": "{\n  \"uris\":[\n\n  ],\n  \"application_name\":\"CommonService-DataWorker-1.0.3\",\n  \"space_name\":\"Production\",\n  \"cf_api\":\"https://api.wise-paas.com\",\n  \"name\":\"CommonService-DataWorker-1.0.3\",\n  \"application_uris\":[\n\n  ],\n  \"space_id\":\"d47dcdd7-ee81-47da-a732-146d358d97e8\",\n  \"application_id\":\"3ab4b683-159c-4c70-80b2-3b854cfdb98b\",\n  \"version\":\"85ccd9b2-f611-4f13-9e6d-89c908748761\",\n  \"limits\":{\n     \"disk\":512,\n     \"fds\":16384,\n     \"mem\":512\n  },\n  \"users\":null,\n  \"application_version\":\"85ccd9b2-f611-4f13-9e6d-89c908748761\"\n}",
                  "type": "json"
              }
          ]
      },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/application/AppAPIDoc.java",
      "groupTitle": "AppInfo"
  },
    {
        "type": "GET",
        "url": "v1/appinfo/version",
        "title": "Get Application Version",
        "name": "GET_API_2",
        "group": "AppInfo",
        "version": "1.0.0",
        "description": "<p>Retrieve the version of application.</p>",
        "success": {
            "examples": [
                {
                    "title": "Response Example(json)",
                    "content": "{\n  \"Version\":\"1.0.3\"\n}",
                    "type": "json"
                }
            ]
        },
        "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/application/AppAPIDoc.java",
        "groupTitle": "AppInfo"
    },
    {
        "type": "GET",
        "url": "/v1/iothub/credential",
    "title": "Get Credentials",
    "name": "GET_API_1",
        "group": "WISE_IoTHub",
    "version": "1.0.0",
        "description": "<p>Retrieve all credentials of WISE IoTHub information.</p>",
    "success": {
      "examples": [
        {
            "title": "Response Example(json)",
            "content": "{\n  \"management\":{\n     \"password\":\"aqekp0vs2mi93eb7u51d0q366l\",\n     \"port\":15672,\n     \"ssl\":false,\n     \"username\":\"955a0600-90a0-42f6-946a-6d532e4bfded\"\n  },\n  \"amqp\":{\n     \"vhost\":\"a4632c1e-269e-41e6-907b-da8ca302dfbd\",\n     \"password\":\"aqekp0vs2mi93eb7u51d0q366l\",\n     \"port\":5672,\n     \"ssl\":false,\n     \"username\":\"955a0600-90a0-42f6-946a-6d532e4bfded\"\n  },\n  \"mqtt\":{\n     \"password\":\"aqekp0vs2mi93eb7u51d0q366l\",\n     \"port\":1883,\n     \"ssl\":false,\n     \"username\":\"a4632c1e-269e-41e6-907b-da8ca302dfbd:955a0600-90a0-42f6-946a-6d532e4bfded\"\n  },\n  \"stomp\":{\n     \"vhost\":\"a4632c1e-269e-41e6-907b-da8ca302dfbd\",\n     \"password\":\"aqekp0vs2mi93eb7u51d0q366l\",\n     \"port\":61613,\n     \"ssl\":false,\n     \"username\":\"955a0600-90a0-42f6-946a-6d532e4bfded\"\n  },\n  \"ws\":{\n     \"vhost\":\"a4632c1e-269e-41e6-907b-da8ca302dfbd\",\n     \"password\":\"aqekp0vs2mi93eb7u51d0q366l\",\n     \"port\":15674,\n     \"ssl\":false,\n     \"username\":\"955a0600-90a0-42f6-946a-6d532e4bfded\"\n  }\n}",
          "type": "json"
        }
      ]
    },
        "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/service/ServiceAPIDoc.java",
        "groupTitle": "WISE_IoTHub"
  },
  {
    "type": "GET",
      "url": "/v1/iothub/credential?<Parameter>",
    "title": "Get Credential",
    "name": "GET_API_2",
      "group": "WISE_IoTHub",
    "version": "1.0.0",
      "description": "<p>Retrieve specific credential information by protocol name.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "String",
            "optional": false,
              "field": "protocol",
              "description": "<p>protocol name, eq: MQTT, AMQP, Management, ws, stomp.</p>"
          }
        ]
      },
        "examples": [
            {
                "title": "URL-Parameter Pattern",
                "content": "protocol=<protocol>",
                "type": "xml"
            }
        ]
    },
    "success": {
      "examples": [
        {
            "title": "Response Example(json)",
            "content": "{\n  \"amqp\":{\n     \"vhost\":\"a4632c1e-269e-41e6-907b-da8ca302dfbd\",\n     \"password\":\"aqekp0vs2mi93eb7u51d0q366l\",\n     \"port\":5672,\n     \"ssl\":false,\n     \"username\":\"955a0600-90a0-42f6-946a-6d532e4bfded\"\n  }\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/service/ServiceAPIDoc.java",
      "groupTitle": "WISE_IoTHub"
  },
  {
    "type": "GET",
    "url": "/v1/data/<primary-key>/latestdata?<Parameter>",
    "title": "Get Latest Data",
    "name": "GET_API_1",
    "group": "data",
    "version": "1.0.0",
    "description": "<p>Retrieve lastest data by device Id. The determination is the process time of server.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"connected\":false,\n  \"itemList\":[\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"sv\":\"ARK-DS520\",\n        \"sensorId\":\"/Platform Information/Board name\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"v\":136957,\n        \"sensorId\":\"/DiskInfo/Disk C Total Disk Space\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/data/DataAPIDoc.java",
    "groupTitle": "data"
  },
  {
    "type": "GET",
    "url": "/v1/data/<primary-key>/histdata?<Parameter>",
    "title": "Get Hist Data",
    "name": "GET_API_2",
    "group": "data",
    "version": "1.0.0",
    "description": "<p>Retrieve historic data by device Id from a range. The maximum number of values is 10000. The determination is the process time of server.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "amount",
            "description": "<p>Amount</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "order",
            "description": "<p>Order, e.g., asc or desc</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>&beginTs=<beginTs>&endTs=<endTs>&amount=<amount>&order=<order>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"connected\":false,\n  \"total\":4,\n  \"itemList\":[\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:55:055\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:55:055\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:45:045\"\n     },\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:45:045\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/data/DataAPIDoc.java",
    "groupTitle": "data"
  },
  {
    "type": "GET",
    "url": "/v1/data/<primary-key>/statisticdata?<Parameter>",
    "title": "Get Statistic Data",
    "name": "GET_API_3",
    "group": "data",
    "version": "1.0.0",
    "description": "<p>Retrieve statistic data by device Id from a range. (Less than 31 days.) The determination is the process time of server.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>&beginTs=<beginTs>&endTs=<endTs>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"unit\":\"Day\",\n  \"itemList\":[\n     {\n        \"val\":\"250\",\n        \"unit\":\"2017-03-06\",\n        \"count\":\"10\"\n     },\n     {\n        \"val\":\"250\",\n        \"unit\":\"2017-03-07\",\n        \"count\":\"9\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/data/DataAPIDoc.java",
    "groupTitle": "data"
  },
  {
    "type": "GET",
    "url": "/v1/data/<primary-key>/latestdata_by_opts?<Parameter>",
    "title": "Get Latest Data(op)",
    "name": "GET_API_4",
    "group": "data",
    "version": "1.0.0",
    "description": "<p>Retrieve lastest data by device Id. The determination is the operation time of agent.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"connected\":false,\n  \"itemList\":[\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"sv\":\"ARK-DS520\",\n        \"sensorId\":\"/Platform Information/Board name\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"v\":136957,\n        \"sensorId\":\"/DiskInfo/Disk C Total Disk Space\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/data/DataAPIDoc.java",
    "groupTitle": "data"
  },
  {
    "type": "GET",
    "url": "/v1/data/<primary-key>/histdata_by_opts?<Parameter>",
    "title": "Get Hist Data(op)",
    "name": "GET_API_5",
    "group": "data",
    "version": "1.0.0",
    "description": "<p>Retrieve historic data by device Id from a range. The maximum number of values is 10000. The determination is the operation time of agent.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "amount",
            "description": "<p>Amount</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "order",
            "description": "<p>Order, e.g., asc or desc</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>&beginTs=<beginTs>&endTs=<endTs>&amount=<amount>&order=<order>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"connected\":false,\n  \"total\":4,\n  \"itemList\":[\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:55:055\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:55:055\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:45:045\"\n     },\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:45:045\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/data/DataAPIDoc.java",
    "groupTitle": "data"
  },
  {
    "type": "GET",
    "url": "/v1/data/<primary-key>/statisticdata_by_opts?<Parameter>",
    "title": "Get Statistic Data(op)",
    "name": "GET_API_6",
    "group": "data",
    "version": "1.0.0",
    "description": "<p>Retrieve statistic data by device Id from a range. (Less than 31 days.) The determination is the operation time of agent.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>&beginTs=<beginTs>&endTs=<endTs>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"unit\":\"Day\",\n  \"itemList\":[\n     {\n        \"val\":\"250\",\n        \"unit\":\"2017-03-06\",\n        \"count\":\"10\"\n     },\n     {\n        \"val\":\"250\",\n        \"unit\":\"2017-03-07\",\n        \"count\":\"9\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/data/DataAPIDoc.java",
    "groupTitle": "data"
  },
  {
    "type": "delete",
    "url": "/v1/devices/<Primary-key>",
    "title": "Delete Device (Deprecated)",
    "name": "DELETE_API_1",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Delete specific device by device Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "GET",
    "url": "/v1/devices",
    "title": "Get Devices",
    "name": "GET_API_1",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve all device information.</p>",
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"devices\":[\n     {\n        \"connected\":false,\n        \"agentId\":\"00000005-0000-0000-000a-rkksa0451099\",\n        \"name\":\"WISE-152cc0\",\n        \"coordinates\":\"25.037531,121.5639969\",\n        \"createTS\":\"2017-04-05 15:42:48.745\",\n        \"did\":2,\n        \"parentId\":\"\",\n        \"loginTS\":\"2017-04-05 15:42:48.745\"\n     },\n     {\n        \"connected\":false,\n        \"agentId\":\"00000001-0000-0000-0000-000babbb7ef5\",\n        \"name\":\"ARK-DS52cc0\",\n        \"coordinates\":\"25.037531,121.5639969\",\n        \"createTS\":\"2017-04-05 15:42:48.744\",\n        \"did\":1,\n        \"parentId\":\"00000001-0000-0000-0000-000babbb7ef4\",\n        \"loginTS\":\"2017-04-05 15:42:48.744\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "GET",
    "url": "/v1/devices/<primary-key>",
    "title": "Get Device",
    "name": "GET_API_2",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve specific device information by device Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"devices\":[\n     {\n        \"connected\":true,\n        \"agentId\":\"00000001-0000-0000-0000-000babbb7ef3\",\n        \"name\":\"ARK-DS520\",\n        \"coordinates\":\"25.037531,121.5639969\",\n        \"parentId\":\"00000001-0000-0000-0000-000babbb7ef4\",\n        \"createTS\":\"2017-02-07 11:22:33.526\",\n        \"did\":1,\n        \"loginTS\":\"2017-02-07 11:22:33.526\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "GET",
    "url": "/v1/devices/<primary-key>/plugins_within_timerange?<Parameter>",
    "title": "Get Plugins/Device within a time range",
    "name": "GET_API_3",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve plugins by device Id from a range. The maximum number of values is 10000.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "amount",
            "description": "<p>Amount</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "order",
            "description": "<p>Order, e.g., asc or desc</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&beginTs=<beginTs>&endTs=<endTs>&amount=<amount>&order=<order>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"total\":4,\n  \"plugins\":[\n     {\n        \"plugin\":\"ProcessMonitor\"\n     },\n     {\n        \"plugin\":\"NetMonitor\"\n     },\n     {\n        \"plugin\":\"SUSIControl\"\n     },\n     {\n        \"plugin\":\"HDDMonitor\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "GET",
    "url": "/v1/devices/<primary-key>/sensors",
    "title": "Get Sensors/Device",
    "name": "GET_API_4",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve sensors by device Id &amp; plugin from a range. The maximum number of values is 10000.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "amount",
            "description": "<p>Amount</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "order",
            "description": "<p>Order, e.g., asc or desc</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&beginTs=<beginTs>&endTs=<endTs>&amount=<amount>&order=<order>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"total\":5,\n  \"sensorIds\":[\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/hddType\"\n     },\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/hddName\"\n     },\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/hddIndex\"\n     },\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/powerOnTime\"\n     },\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/hddHealthPercent\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "Post",
    "url": "/v1/devices",
    "title": "Add Devices",
    "name": "POST_API_1",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Add device information.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "name",
            "description": "<p>Device name</p>"
          },
          {
            "group": "Body Content",
            "type": "boolean",
            "optional": true,
            "field": "connected",
            "description": "<p>Device connected status</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "coordinates",
            "description": "<p>Device location (latitude and longitude)</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "parentId",
            "description": "<p>Device parent Id</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"device\":[\n     {\n        \"agentId\":\"00000001-0000-0000-0000-000babbb7ef3\",\n        \"name\":\"ARK-DS520\",\n        \"connected\":true,\n        \"coordinates\":\"25.037531,121.5639969\",\n        \"parentId\":\"00000001-0000-0000-0000-000babbb7ef4\"\n     },\n     {\n        \"agentId\":\"00000005-0000-0000-000a-rkksa0451097\",\n        \"name\":\"WISE-1520\",\n        \"connected\":false,\n        \"coordinates\":\"25.037531,121.5639969\",\n     }\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "put",
    "url": "/v1/devices",
    "title": "Edit Devices",
    "name": "PUT_API_1",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Edit specific device information by device Id.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "did",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "name",
            "description": "<p>Device name</p>"
          },
          {
            "group": "Body Content",
            "type": "boolean",
            "optional": true,
            "field": "connected",
            "description": "<p>Device connected status</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "coordinates",
            "description": "<p>Device location (latitude and longitude)</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "parentId",
            "description": "<p>Device parent Id</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"device\":[\n     {\n        \"did\":1,\n        \"agentId\":\"00000001-0000-0000-0000-000babbb7ef3\",\n        \"name\":\"ARK-DS520\",\n        \"connected\":true,\n        \"coordinates\":\"25.037531,121.5639969\",\n        \"parentId\":\"00000001-0000-0000-0000-000babbb7ef4\"\n     },\n     {\n        \"did\":2,\n        \"agentId\":\"00000005-0000-0000-000a-rkksa0451097\",\n        \"name\":\"WISE-1520\",\n        \"connected\":false,\n        \"coordinates\":\"25.037531,121.5639969\"\n     }\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
      "filename": "D:/work/EI-Common/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  }
] });
