Create Customized Widget
================

Overview
----------

EI-DashBoard widget is extensible for flexible used.

This guide will help you customize a widget and exactly implement in I-Dashboard.

- Customized Widget
- JavaScript File
- Widget Settings Properties
- New Widget Instance
- Widget Instance Properties
- Include Widget

Customized Widget
--------------

Widgets get created when a dashboard is initialized, each widget instance is created by settings. They reveive data when value changed.

A JavaScript file defines what the widget does and what the setting’s properties.

After included into main program, you can see the customized widget which just be created on widget type dropdown list.

All widget function and feature is developed and defined in JavaScript.

JavaScript File
----------

The file is also located in the widget directory of your user directory: under `~/js/FreeBoard/plugins/freeboard/wg/` folder.

Clone a widget file then customized a new widget.

The following template is a simple widget instance.

    (function () {
    /*i18n*/
    if (typeof (i18n) != 'undefined') {
    i18n.addResource('en', 'translation', '', '');
    }
    freeboard.loadWidgetPlugin({
    type_name: 'templateWidget',
    display_name: 'Template Widget',
    fill_size: true,
    settings: [
    {
    name: 'title',
    validate: 'optional,maxSize[100]',
    display_name: 'title',
    type: 'text'
    },
    {
    name: 'Value',
    display_name: 'Value',
    description: 'Value Of Data Source ',
    type: 'calculated'
    },
    {
    name: "height",
    display_name: "height",
    validate: "required,custom[integer],min[1],max[20]",
    type: "number",
    default_value: 1,
    description: "",
    addClass: 'advancedSetting'
    }
    ],
    newInstance: function (settings, newInstanceCallback)
    {
    newInstanceCallback(new templateWidget(settings));
    }
    });
    var templateWidget = function (settings)
    {
    var self = this;
    var currentSettings = settings;
    var titleElement = $('
    ');
    var currentID = _.uniqueId('wgd_');
    var widgetElement = $('
    ');
    self.getHeight = function ()
    {
    return currentSettings.height;;
    };
    
    self.render = function (containerElement)
    {
    $(containerElement).append(titleElement).append(widgetElement);
    widgetElement.append('');
    };
    self.onSettingsChanged = function (newSettings)
    {
    currentSettings = newSettings;
    titleElement.html((_.isUndefined(currentSettings.title) ? '' : currentSettings.title));
    };
    self.onCalculatedValueChanged = function (settingName, newValue)
    {
    widgetElement.find("a").html(newValue);
    };
    self.onDispose = function ()
    {
    };
    };
    }());
                            
The widget object is defined by a function. The function calls the `freeboard.loadWidgetPlugin` function to initialize each widget setting option. After `newInstanceCallback(new templateWidget(settings))`, the widget object is created.

A widget .js file defines following things:

- the setting option for each widget
- what widget instance do after initialized

Widget Settings Properties
--------------

A widget must be defined with `freeboard.loadWidgetPlugin`.

It's a definition that tells dashboard that we are giving it a widget plugin. It expects an object with the following:

    type_name: 'templateWidget',
    display_name: 'Template Widget',
    fill_size: true,
    settings: [
    {
    name: 'title',
    validate: 'optional,maxSize[100]',
    display_name: 'title',
    type: 'text'
    },
    {
    name: 'Value',
    display_name: 'Value',
    description: 'Value Of Data Source ',
    type: 'calculated'
    },
    {
    name: "height",
    display_name: "height",
    validate: "required,custom[integer],min[1],max[20]",
    type: "number",
    default_value: 1,
    description: "",
    addClass: 'advancedSetting'
    }
    ],
                            
- type_name*: An unique name for this widget. This name should be as unique as possible to avoid collisions with other widget, and should follow naming conventions for javascript variable and function declarations.
- display_name: The pretty name that will be used for display purposes for this widget. If the name is not defined, type_name will be used instead.
- fill_size: If this is set to true, the widget will fill be allowed to fill the entire space given it, otherwise it will contain an automatic padding of around 10 pixels around it.
- settings: An array of settings that will be displayed for this widget when the user adds it.
	- name: The name of the setting. This value will be used in your code to retrieve the value specified by the user. This should follow naming conventions for javascript variable and function declarations.
	- display_name: The pretty name that will be shown to the user when they adjust this setting.
	- description: Text that will be displayed below the setting to give the user any extra information.
	- default_value: A default value for this setting.
	- required: If set to true, the field will be required to be filled in by the user. Defaults to false if not specified.
	- type*: The type of input expected for this setting.
	
|Name	| Description |
|--------|---------- |
|Type	|Display a single text box input. Examples of other types will follow in this documentation.|
|number	|Display a data of a numerical type which requires the user to enter a numerical value.|
|calculated	|This is a special text input box that may contain javascript formulas and references to datasources in the dashboard. We'll use a calculated setting because we want what's displayed in this widget to be dynamic based on something changing (like a datasource).|
|boolean	|Display a checkbox indicating a true/false setting.|
|option	|Display a dropdown box with a list of choices.|

- options: An array of options to be populated in the dropdown.

|Name	|Description|
|-------|-----------|
|name*	|The text to be displayed in the dropdown.|
|value	|The value of the option. If not specified, the name parameter will be used.|

New Widget Instance
----------

Once a widget setting is saved, a new widget instance will be created with the setting.

    freeboard.loadWidgetPlugin({
    // widget option definition
    ...
    newInstance: function(settings, newInstanceCallback)
    {
    newInstanceCallback(new myWidgetPlugin(settings));
    }
    });
 
    var myWidgetPlugin = function(settings)
    {
    // widget instance
    ...
    }
                        
Widget Instance Properties
--------------

The widget instance object is also defined in the widget directory of your user directory, typically `~/js/FreeBoard/plugins/freeboard/wg`.

    self.getHeight = function ()
    {
    return currentSettings.height;;
    };
    
    self.render = function (containerElement)
    {
    $(containerElement).append(titleElement).append(widgetElement);
    widgetElement.append('');
    };
     
    self.onSettingsChanged = function (newSettings)
    {
    currentSettings = newSettings;
    titleElement.html((_.isUndefined(currentSettings.title) ? '' : currentSettings.title));
    };
     
    self.onCalculatedValueChanged = function (settingName, newValue)
    {
    widgetElement.find("a").html(newValue);
    };
     
    self.onDispose = function ()
    {
    };
 
                            
- self.render*: A public function we must implement that will be called when freeboard wants us to render the contents of our widget. The container element is the DIV that will surround the widget.
- self.getHeight*: A public function we must implement that will be called when freeboard wants to know how big we expect to be when we render, and returns a height. This function will be called any time a user updates their settings (including the first time they create the widget). Note here that the height is not in pixels, but in blocks. A block in freeboard is currently defined as a rectangle that is fixed at 300 pixels wide and around 45 pixels multiplied by the value you return here.
- self.onSettingsChanged*: A public function we must implement that will be called when a user makes a change to the settings.
- self.onCalculatedValueChanged*: A public function we must implement that will be called when a calculated value changes. Since calculated values can change at any time (like when a datasource is updated) we handle them in a special callback function here.
- self.onDispose*: A public function we must implement that will be called when this instance of this plugin is no longer needed. Do anything you need to cleanup after yourself here.

Include Widget
----------

After both customized widget plugin and insiance are finshed, the widget `.js` file need to be included in EI-DashBoard main page.

The file is also in the js page module folder of your user directory: `~Freeboard.html`.

    <html>
    <head>
    </head>
    <body>
    ...
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/plugin.wg.text.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/plugin.wg.picture.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/plugin.wg.html.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/plugin.wg.pointer.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/plugin.wg.indicator.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/plugin.wg.gauge.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/SA.wg.fans.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/SA.wg.progressbar.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/plugin.wg.ragIndicator.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/SA.wg.OnOff.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/SA.wg.nodeRedTreshold.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/SA.wg.table.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/plugin.wg.c3js.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/SA.wg.multigooglemap.js">
    <script type="text/javascript" defer="defer" src="plugins/freeboard/wg/Customization/plugin.wg.[template].js">
    ...
    </body>
    </html>
 
                            
Add below function to include new widgets: `<widget file path>`.