Iot Hub User Guide
===

**Version**: 1.0.0

This guide will demonstrate how to extract connection information of **IoT Hub** by using **Python**, **NodeJS**, and **Java**.


VCAP_SERVICES
---

**EI-PaaS** will keep information of **IoT Hub** in the environment variable named **VCAP_SERVICES** in applications.

It will looks like:
```javascript
{
    "VCAP_SERVICES":{
        "p-rabbitmq":[
            {
                "credentials":{
                    "http_api_uris":[
                        "https://a8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@pivotal-rabbitmq.example.com/api/"
                    ],
                    "ssl":false,
                    "dashboard_url":"https://pivotal-rabbitmq.example.com/#/login/a8fa89d2-b98b-4803-b4be-463b38ca5354/paf5hvf88pja7f5ilebpktbr3f",
                    "password":"paf5hvf88pja7f5ilebpktbr3f",
                    "protocols":{
                        "amqp":{
                            "vhost":"5af18cfd-08e1-495c-87c6-87f3414deabb",
                            "username":"a8fa89d2-b98b-4803-b4be-463b38ca5354",
                            "password":"paf5hvf88pja7f5ilebpktbr3f",
                            "port":5672,
                            "host":"rabbitmq.example.com",
                            "hosts":[
                                "rabbitmq.example.com"
                            ],
                            "ssl":false,
                            "uri":"amqp://a8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@rabbitmq.example.com:5672/5af18cfd-08e1-495c-87c6-87f3414deabb",
                            "uris":[
                                "amqp://a8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@rabbitmq.example.com:5672/5af18cfd-08e1-495c-87c6-87f3414deabb"
                            ]
                        },
                        "management":{
                            "path":"/api/",
                            "ssl":false,
                            "hosts":[
                                "rabbitmq.example.com"
                            ],
                            "password":"paf5hvf88pja7f5ilebpktbr3f",
                            "username":"a8fa89d2-b98b-4803-b4be-463b38ca5354",
                            "port":15672,
                            "host":"rabbitmq.example.com",
                            "uri":"http://a8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@rabbitmq.example.com:15672/api/",
                            "uris":[
                                "http://a8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@rabbitmq.example.com:15672/api/"
                            ]
                        },
                        "mqtt":{
                            "username":"5af18cfd-08e1-495c-87c6-87f3414deabb:a8fa89d2-b98b-4803-b4be-463b38ca5354",
                            "password":"paf5hvf88pja7f5ilebpktbr3f",
                            "port":1883,
                            "host":"rabbitmq.example.com",
                            "hosts":[
                                "rabbitmq.example.com"
                            ],
                            "ssl":false,
                            "uri":"mqtt://5af18cfd-08e1-495c-87c6-87f3414deabb%3Aa8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@rabbitmq.example.com:1883",
                            "uris":[
                                "mqtt://5af18cfd-08e1-495c-87c6-87f3414deabb%3Aa8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@rabbitmq.example.com:1883"
                            ]
                        }
                    },
                    "username":"a8fa89d2-b98b-4803-b4be-463b38ca5354",
                    "hostname":"rabbitmq.example.com",
                    "hostnames":[
                        "rabbitmq.example.com"
                    ],
                    "vhost":"5af18cfd-08e1-495c-87c6-87f3414deabb",
                    "http_api_uri":"https://a8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@pivotal-rabbitmq.example.com/api/",
                    "uri":"amqp://a8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@rabbitmq.example.com/5af18cfd-08e1-495c-87c6-87f3414deabb",
                    "uris":[
                        "amqp://a8fa89d2-b98b-4803-b4be-463b38ca5354:paf5hvf88pja7f5ilebpktbr3f@rabbitmq.example.com/5af18cfd-08e1-495c-87c6-87f3414deabb"
                    ]
                },
                "syslog_drain_url":null,
                "volume_mounts":[

                ],
                "label":"p-rabbitmq",
                "provider":null,
                "plan":"standard",
                "name":"rabbitmq",
                "tags":[
                    "rabbitmq",
                    "messaging",
                    "message-queue",
                    "amqp",
                    "stomp",
                    "mqtt",
                    "pivotal"
                ]
            }
        ]
    }
}
```


Python
---

The code of **Python** to extract uris of **amqp** and **mqtt** will looks like:

```python
import os
import json


# Load 'VCAP_SERVICES' from enviroment variable and parse the URI of IoT Hub
vcap_services = os.getenv('VCAP_SERVICES')
vcap_services = json.loads(vcap_services)
amqp_uri = vcap_services['p-rabbitmq'][0]['credentials']['protocols']['amqp']['uri']
mqtt_uri = vcap_services['p-rabbitmq'][0]['credentials']['protocols']['mqtt']['uri']
```

After extract the connection information, you can reference the [RabbitMQ tutorials](https://www.rabbitmq.com/tutorials/tutorial-one-python.html) of **Python** to learn how to use **IoT Hub**.


NodeJS
---

The code of **NodeJS** to extract uris of **amqp** and **mqtt** will looks like:

```javascript
vcap_services = process.env.VCAP_SERVICES
amqp_uri = vcap_services.p-rabbitmq[0].credentials.protocols.amqp.uri
mqtt_uri = vcap_services.p-rabbitmq[0].credentials.protocols.mqtt.uri
```
After extract the connection information, you can reference the [RabbitMQ tutorials](https://www.rabbitmq.com/tutorials/tutorial-one-javascript.html) of **NodeJS** to learn how to use **IoT Hub**.

Java
---

For convenience, use **json** to parse **VCAP_SERVICES** is recommended.
So, add the library **json** to your **pom.xml**:
```
<repositories>
    <dependency>
        <groupId>org.json</groupId>
        <artifactId>json</artifactId>
        <version>20160810</version>
    </dependency>
</repositories>
```

And the code to extract uris of **amqp** and **mqtt** will looks like:
```java
import org.json.JSONObject;

JSONObject vcapServices = new JSONObject(System.getenv("VCAP_SERVICES"));
String amqpURI = vcapServices.getJSONArray("p-rabbitmq").getJSONObject(0).getJSONObject("credentials").getJSONObject("protocols").getJSONObject("amqp").getString("uri");
String mqttURI = vcapServices.getJSONArray("p-rabbitmq").getJSONObject(0).getJSONObject("credentials").getJSONObject("protocols").getJSONObject("mqtt").getString("uri");
```

After extract the connection information, you can reference the [RabbitMQ tutorials](https://www.rabbitmq.com/tutorials/tutorial-one-java.html) of **Java** to learn how to use **IoT Hub**.
