Local Development Environment Installation Guide
==========


For those developers who don’t like to develop with virtual machine, this guide provides helpful information for installing development environment locally.


Pre-operation(for GUI software)
-----------

Install terminal for gui

    apt-get gnome-terminal

Install gui

    apt-get install --no-install-recommends ubuntu-desktop

Reboot to initial gui

    shutdown -r now

Language and package tool
----------

**Pip 9.0.1**

Download the pip install script


    wget https://bootstrap.pypa.io/get-pip.py

Execute the python script to install pip

    python get-pip.py

**Ruby 2.3.1 & Rubygem 2.5.1**

Install ruby

    sudo apt-get install ruby


**Java 1.8.0_121**

Install java

    sudo apt-get install default-jdk

Setting JAVA_HOME


    sudo vi /etc/environment
    JAVA_HOME="/usr/lib/jvm/java-8-openjdk-amd64/jre"

    sudo vi ~/.bashrc

    export JAVA_HOME=/usr/lib/jvm/java-8-openjdk-amd64/jre
    export PATH=$JAVA_HOME/bin:$PATH
    source ~/.bashrc

**Node.js 4.2.6**

Install nodejs


    sudo apt-get install nodejs

**R 3.4.0**

Add package key and update apt database

    sudo apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys E298A3A825C0D65DFD57CBB651716619E084DAB9
    
	sudo add-apt-repository 'deb [arch=amd64,i386] https://cran.rstudio.com/bin/linux/ubuntu xenial/'
    
	sudo apt-get update

Install r

    sudo apt-get install r-base

## Database

**MongoDB 3.4.4**

Add package key and update apt database

    sudo apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv 0C49F3730359A14518585931BC711F9BA15703C6

    echo "deb [ arch=amd64,arm64 ] http://repo.mongodb.org/apt/ubuntu xenial/mongodb-org/3.4 multiverse" | sudo tee /etc/apt/sources.list.d/mongodb-org-3.4.list

    sudo apt-get update

Install mongodb

    sudo apt-get install mongodb-org

Start mongodb

    sudo service mongod start


**Postgresql 9.6**

Add package key and update apt database

    sudo add-apt-repository "deb http://apt.postgresql.org/pub/repos/apt/ xenial-pgdg main"

    wget --quiet -O - https://www.postgresql.org/media/keys/ACCC4CF8.asc | \
     sudo apt-key add -

    sudo apt-get update

Install postgres

    sudo apt-get install postgresql-9.6

Common tool
--------

**Cloud Foundry CLI 6.26.0**

Add package key and update apt database

    wget -q -O - https://packages.cloudfoundry.org/debian/cli.cloudfoundry.org.key | sudo apt-key add -

    echo "deb http://packages.cloudfoundry.org/debian stable main" | sudo tee /etc/apt/sources.list.d/cloudfoundry-cli.list

    sudo apt-get update

Install cloud foundry cli

    sudo apt-get install cf-cli

**UAAC 3.10.0**

Install compilier and ruby

    sudo apt-get install ruby
    sudo apt-get install ruby-dev
    sudo apt-get install build-essential

Install UAAC

    sudo gem install cf-uaac

**Chromium 58.0+ plugin Postman**

Install gui before installing chromium

Install chromium

    sudo apt-get install chromium-browser

Install postman

    chromium-browser https://chrome.google.com/webstore/detail/postman/fhbjgbiflinjbdggehcddcbncdddomop

Click “Add to chrome”


**Maven 3.3.9**

Install JAVA and setting JAVA_HOME before install Maven

Install maven

    sudo apt-get install maven


**Tomcat 8.5.14**

Install JAVA and setting JAVA_HOME before installing Tomcat

For security purposes, Tomcat should be run as an unprivileged user (i.e. not root). We will create a new user and group that will run the Tomcat service.

    sudo groupadd tomcat
    sudo useradd -s /bin/false -g tomcat -d /opt/tomcat tomcat

Download tomcat install file

    sudo wget http://ftp.tc.edu.tw/pub/Apache/tomcat/tomcat-8/v8.5.14/bin/apache-tomcat-8.5.14.tar.gz

    sudo tar -xzvf apache-tomcat-8.5.14.tar.gz

    sudo mkdir /opt/tomcat
    
    sudo mv apache-tomcat-8.5.14/* /opt/tomcat/
    
    sudo rm -r apache-tomcat-8.5.14.tar.gz apache-tomcat-8.5.14

Update permissions
    sudo chgrp -R tomcat /opt/tomcat
    
    sudo chmod -R 755 /opt/tomcat/
    
    sudo chmod g+x /opt/tomcat/conf
    
    sudo chown -R tomcat /opt/tomcat/webapps/ /opt/tomcat/work/ /opt/tomcat/temp/ /opt/tomcat/logs/
    
Setting tomcat path

    sudo vi ~/.bashrc
    export CATALINA_HOME=/opt/tomcat
    source ~/.bashrc

Setting tomcat service file

    sudo vi /etc/systemd/system/tomcat.service

    [Unit]
    Description=Apache Tomcat 8 Servlet Container
    After=syslog.target network.target
    
    [Service]
    User=tomcat
    Group=tomcat
    Type=forking
    Environment=CATALINA_PID=/opt/tomcat/tomcat.pid
    Environment=CATALINA_HOME=/opt/tomcat
    Environment=CATALINA_BASE=/opt/tomcat
    ExecStart=/opt/tomcat/bin/startup.sh
    ExecStop=/opt/tomcat/bin/shutdown.sh
    Restart=on-failure
    
    [Install]
    WantedBy=multi-user.target


    sudo vi /opt/tomcat/conf/tomcat-users.xml
    <role rolename="manager-gui"/>
    <user username="appdev" password="appdev" roles="manager-gui,admin-gui"/>

(Below two items modified to be disable)

    sudo vi /opt/tomcat/webapps/manager/META-INF/context.xml

    <Context antiResourceLocking="false" privileged="true" >
    <!-- <Valve className="org.apache.catalina.valves.RemoteAddrValve"
     allow="127\.\d+\.\d+\.\d+|::1|0:0:0:0:0:0:0:1" /> -->
    </Context>

    sudo vi /opt/tomcat/webapps/host-manager/META-INF/context.xml

    <Context antiResourceLocking="false" privileged="true" >
    <!-- <Valve className="org.apache.catalina.valves.RemoteAddrValve"
     allow="127\.\d+\.\d+\.\d+|::1|0:0:0:0:0:0:0:1" /> -->
    </Context>

Start tomcat

    sudo systemctl daemon-reload 
    sudo systemctl start tomcat    
    sudo systemctl enable tomcat


**Rabbitmq 3.5.7**

Install rabbitmq

    sudo apt-get install rabbitmq-server


**Freeboard**

Install browser(like chromium) before installing Freeboard
Install nodejs before installing freeboard

Download freeboard source code

    git clone https://github.com/Freeboard/freeboard.git
    cd freeboard

Install package and package code

    npm install
    grunt

Open freeboard

 - chromium-browser index.html


**Node red 0.16.2**

Install nodejs before installing node red

Install node red

    sudo npm install -g node-red

## IDE

Install gui before installing IDE

**Eclipse 3.8.1**

Install eclipse

    sudo apt-get install eclipse


**Netbeans8.2**

Download netbeans install script

    wget http://download.netbeans.org/netbeans/8.2/final/bundles/netbeans-8.2-javase-linux.sh

Execute script to install netbeans

    sudo sh ./netbeans-8.2-javase-linux.sh


**IntelliJ IDEA 2017.1.1**

Download IntelliJ IDEA and unzip file

    wget https://download.jetbrains.com/idea/ideaIC-2017.1.1.tar.gz
    
    tar -zxvf ideaIC-2017.1.1.tar.gz
Execute install script

    sudo sh idea-IC-171.4073.35/bin/idea.sh


**VScode 1.12.1**

Install browser(like chromium) before installing VScode

Download VScode install package

- chromium-browser https://go.microsoft.com/fwlink/?LinkID=760868

Install VScode

    sudo dpkg -i code_1.12.1-1493934083_amd64.deb


