EI-PaaS Single Sign-On Tutorial
===

EI-PaaS now applies the single sign-on authentication scheme. With single sign-on, users can only login once to access different web applications on EI-PaaS.

Single sign-on supports two ways to login, the first is web-based, the other one is native-based.

Web based Token Access Method
---

For web based single sign-on token access method, users need to login(For example, Technical Portal) using single sign-on scheme to get WISEAccessToken cookie. Front-end app can't directly get cookie from browser due to security issue.

Now we are going to show you steps to apply web-based single sign-on method if you are developing web application. Otherwise, you can directly login through Technical Portal to get cookie.

**Notice: You need to push web application to PCF first in order to apply this method**

**1. Decide the single sign-on url: Depending on your application in different space, you need to configure the appropriate url**

```javascript

  var siteProtocol = window.location.protocol;
  var siteHostname = window.location.hostname;
  var dotIndex = siteHostname.indexOf('.');
  var singleSignOnDomain = siteHostname.substr(dotIndex + 1) + '/';
  // default single sign-on URL: production
  var singleSignOnURL = siteProtocol + '//portal-sso.' + singleSignOnDomain;
  if (/-stage/g.test(siteHostname))
    singleSignOnURL = siteProtocol + "//portal-sso-stage." + singleSignOnDomain;
  if (/-develop/g.test(siteHostname))
    singleSignOnURL = siteProtocol + "//portal-sso-develop." + singleSignOnDomain;
    
```
**2. Redirect to Microsoft Azure AD page to login.**

```javascript

  // redirect to Microsoft Azure AD page
  $('#single-sign-on-login-btn').click(function() {
    var redirectURL = 
        'https://login.windows.net/c53d73cb-64c4-4c1d-b972-7f92d1330c39/oauth2/authorize?' +
        'response_type=code&redirect_uri=' + singleSignOnURL + 'web/redirectPage.html&' + 
        'client_id=09ea49b3-09fc-4b9a-b452-52563e9d4add&state=' + window.location.origin;
    window.location.href = redirectURL;
  });  

```

**3. Detect if there is WISEName stored in cookies after redirecting from Microsoft Azure AD page, now you can request API to any web application on EI-PaaS now(cookie will be automatically sent to server within every API now). For example, now you can perform login API to EI-PaaS RMM.**

```javascript
  if (Cookies.get('WISEName')) {
    signInUsingSSO(Cookies.get('WISEAccessToken'))
      .fail(function(xhr) {
        console.log(xhr);
      })
      .done(function(xhr) {
        console.log(xhr);
      });
  }
  
  function signInUsingSSO(token) {
    return $.ajax({
      cache: false,
      url: '/rmm/v1/accounts/login',
      type: 'get',
      contentType: 'application/json',
      dataType: 'json',
      beforeSend: function(xhr) {
        var authorization = 'Bearer ' + $.base64.encode(JSON.stringify(Cookies.get('WISEAccessToken')));
        xhr.setRequestHeader("Authorization", authorization);
        xhr.setRequestHeader("Accept", "application/json");      
      }
    });
  }

```

**4. If you need to sign out from applications, then you can do this**

```javascript
  var redirectURL = singleSignOnURL + 'web/signOut.html';
  window.location.href = redirectURL;
            
```

reference:
1. [SSO Token Access Guide](documents/IoTApp/userguide.md#如何取得Single-Sign-On_Token)


Native based Token Access Method
---

With native based, you can call SSO API to access WISEAppToken. In order to access token, you need to embed appId and userId in JSON format and send to server with POST type. You can find further information on how to access your appId and userId in [Management Portal Space Admin Guide](documents/ManagementPortal/userguide.md#API_Resources).

Now we are going to show you how to apply native-based single sign-on method.

```javascript
  function getNativebasedSSOToken(yourAppId, yourUserId) {
    return $.ajax({
      cache: false,
      url: 'https://portal-sso.wise-paas.com/sso/auth/native',
      type: 'post',
      contentType: 'application/json',
      data: '{"appId": yourAppId,"userId": yourUserId}',
      beforeSend: function (xhr) {}
    });
  }

  getNativebasedSSOToken(yourAppId, yourUserId)
	.fail(function(xhr) {
		console.log(xhr);
	})
	.done(function(xhr) {
		console.log(xhr);
	});

```



