define({ "api": [
  {
    "type": "GET",
    "url": "/v1/appinfo",
    "title": "Get Application Information",
    "name": "GET_API_1",
    "group": "AppInfo",
    "version": "1.0.0",
    "description": "<p>Retrieve all information of application from environment variables.</p>",
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"uris\":[\n\n  ],\n  \"application_name\":\"RMM-Worker-1.0.3\",\n  \"space_name\":\"Production\",\n  \"cf_api\":\"https://api.wise-paas.com\",\n  \"name\":\"RMM-Worker-1.0.3\",\n  \"application_uris\":[\n\n  ],\n  \"space_id\":\"d47dcdd7-ee81-47da-a732-146d358d97e8\",\n  \"application_id\":\"3ab4b683-159c-4c70-80b2-3b854cfdb98b\",\n  \"version\":\"85ccd9b2-f611-4f13-9e6d-89c908748761\",\n  \"limits\":{\n     \"disk\":512,\n     \"fds\":16384,\n     \"mem\":512\n  },\n  \"users\":null,\n  \"application_version\":\"85ccd9b2-f611-4f13-9e6d-89c908748761\"\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/application/AppAPIDoc.java",
    "groupTitle": "AppInfo"
  },
  {
    "type": "GET",
    "url": "v1/appinfo/version",
    "title": "Get Application Version",
    "name": "GET_API_2",
    "group": "AppInfo",
    "version": "1.0.0",
    "description": "<p>Retrieve the version of application.</p>",
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"Version\":\"1.0.3\"\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/application/AppAPIDoc.java",
    "groupTitle": "AppInfo"
  },
  {
    "type": "Delete",
    "url": "/rmm/v1/accounts/<primary-key>",
    "title": "Delete Account",
    "name": "DELETE_API_1",
    "group": "accounts",
    "version": "1.0.0",
    "description": "<p>Delete a specific account by account Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Account Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "accounts"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/accounts?<Parameter>",
    "title": "Get Accounts",
    "name": "GET_API_1",
    "group": "accounts",
    "version": "1.0.0",
    "description": "<p>Retrieve all account information.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "pageSize",
            "description": "<p>Page Size</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "no",
            "description": "<p>Page Number</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "orderType",
            "description": "<p>Order Type</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "orderBy",
            "description": "<p>Order By</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "like",
            "description": "<p>Like Parameter</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "pageSize=<pageSize>&no=<no>&orderType=<orderType>&orderBy=<orderBy>&like=<like>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"accounts\":[\n     {\n        \"firstName\":\"admin\",\n        \"lastName\":\"admin\",\n        \"mail\":\"admin@advantech.com.tw\",\n        \"name\":\"admin\",\n        \"fullName\":\"admin\",\n        \"createTS\":\"2017-01-01 00:00:00.000\",\n        \"rid\":1,\n        \"aid\":1,\n        \"loginTS\":\"2017-01-01 00:00:00.000\"\n     },\n     {\n        \"firstName\":\"fllan\",\n        \"lastName\":\"Chen\",\n        \"mail\":\"allan@advantech.com.tw\",\n        \"name\":\"fllan\",\n        \"fullName\":\"fllan Chen\",\n        \"createTS\":\"2017-03-14 11:19:37.262\",\n        \"rid\":1,\n        \"aid\":3,\n        \"loginTS\":\"2017-03-14 11:19:37.262\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "accounts"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/accounts/<primary-key>",
    "title": "Get Account",
    "name": "GET_API_2",
    "group": "accounts",
    "version": "1.0.0",
    "description": "<p>Retrieve a specific account information by account Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Account Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"accounts\":[\n     {\n        \"firstName\":\"admin\",\n        \"lastName\":\"admin\",\n        \"mail\":\"admin@advantech.com.tw\",\n        \"name\":\"admin\",\n        \"fullName\":\"admin\",\n        \"createTS\":\"2017-01-01 00:00:00.000\",\n        \"rid\":1,\n        \"aid\":1,\n        \"loginTS\":\"2017-01-01 00:00:00.000\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "accounts"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/accounts/login",
    "title": "Login",
    "name": "GET_API_3",
    "group": "accounts",
    "version": "1.0.0",
    "description": "<p>The API for account login, and return permission result.</p>",
    "parameter": {
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "username=<username>&password=<password>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"answer\":true,\n  \"aid\":1\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "accounts"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/accounts/<primary-key>/groups",
    "title": "Get Groups/Account",
    "name": "GET_API_4",
    "group": "accounts",
    "version": "1.0.0",
    "description": "<p>Retrieve group information by account Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Account Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"accounts\":[\n     {\n        \"firstName\":\"\",\n        \"lastName\":\"\",\n        \"mail\":\"teddy15b@gmail.com\",\n        \"name\":\"teddy15b\",\n        \"fullName\":\"teddy15b\",\n        \"groups\":[\n           {\n              \"gid\":1,\n              \"subgroups\":[\n                 {\n                    \"gid\":2,\n                    \"name\":\"Advantech-333F\",\n                    \"description\":\"Group of Advantech 333F\",\n                    \"createTS\":\"2017-04-27 13:30:03.955\",\n                    \"parentGroup\":{\n                       \"gid\":1,\n                       \"name\":\"Advantech-33F\"\n                    },\n                    \"aid\":1\n                 }\n              ],\n              \"name\":\"Advantech-33F\",\n              \"description\":\"Group of Advantech 33F\",\n              \"createTS\":\"2017-04-27 13:30:03.945\",\n              \"aid\":13\n           }\n        ],\n        \"createTS\":\"2017-05-17 10:33:51.306\",\n        \"rid\":2,\n        \"aid\":13,\n        \"loginTS\":\"2017-05-17 10:54:59.607\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "accounts"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/accounts",
    "title": "Add Accounts",
    "name": "POST_API_1",
    "group": "accounts",
    "version": "1.0.0",
    "description": "<p>Add account information.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "rid",
            "description": "<p>Role Id</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "name",
            "description": "<p>Account Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "fullName",
            "description": "<p>Account Full Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "firstName",
            "description": "<p>Account First Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "lastName",
            "description": "<p>Account Last Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "mail",
            "description": "<p>Account Email Address</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "password",
            "description": "<p>Account Password</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "enable",
            "description": "<p>Enable/Disable Current Account</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"accounts\":[\n     {\n        \"rid\":1,\n        \"name\":\"Kevin\",\n        \"fullName\":\"Kevin Chang\",\n        \"firstName\":\"Kevin\",\n        \"lastName\":\"Chang\",\n        \"mail\":\"kevin@advantech.comm.tw\",\n        \"password\":\"P@ssw0rd\",\n        \"enable\":true\n     },\n     {\n        \"rid\":1,\n        \"name\":\"Allan\",\n        \"fullName\":\"Allan Chen\",\n        \"firstName\":\"Allan\",\n        \"lastName\":\"Chen\",\n        \"mail\":\"allan@advantech.com.tw\",\n        \"password\":\"1qaz@WSX\",\n        \"enable\":true\n     }\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "accounts"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/accounts/logout",
    "title": "Logout",
    "name": "POST_API_2",
    "group": "accounts",
    "version": "1.0.0",
    "description": "<p>The API for account logout, and record this event.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "name",
            "description": "<p>Account Name</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"accounts\":{\n     \"name\":\"admin\"\n  }\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n   \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "accounts"
  },
  {
    "type": "Put",
    "url": "/rmm/v1/accounts",
    "title": "Edit Accounts",
    "name": "PUT_API_1",
    "group": "accounts",
    "version": "1.0.0",
    "description": "<p>Edit account information.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "aid",
            "description": "<p>Account Id</p>"
          },
          {
            "group": "Body Content",
            "type": "long",
            "optional": true,
            "field": "rid",
            "description": "<p>Role Id</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "name",
            "description": "<p>Account Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "fullName",
            "description": "<p>Account Full Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "firstName",
            "description": "<p>Account First Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "lastName",
            "description": "<p>Account Last Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "mail",
            "description": "<p>Account Email Address</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "password",
            "description": "<p>Account Password</p>"
          },
          {
            "group": "Body Content",
            "type": "boolean",
            "optional": true,
            "field": "enable",
            "description": "<p>Enable/Disable Current Account</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"accounts\":[\n     {\n        \"aid\":2,\n        \"rid\":1,\n        \"name\":\"Kevin\",\n        \"fullName\":\"Kevin Chang\",\n        \"firstName\":\"Kevin\",\n        \"lastName\":\"Chang\",\n        \"mail\":\"kevin@advantech.comm.tw\",\n        \"password\":\"P@ssw0rd\",\n        \"enable\":true\n     },\n     {\n        \"aid\":3,\n        \"rid\":1,\n        \"name\":\"Allan\",\n        \"fullName\":\"Allan Chen\",\n        \"firstName\":\"Allan\",\n        \"lastName\":\"Chen\",\n        \"mail\":\"allan@advantech.com.tw\",\n        \"password\":\"1qaz@WSX\",\n        \"enable\":true\n     }\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "accounts"
  },
  {
    "type": "GET",
    "url": "/v1/devicectrl/<primary-key>/latestdata?<Parameter>",
    "title": "Get Latest Data",
    "name": "GET_API_1",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Retrieve lastest data by device Id. The determination is the process time of server.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"connected\":false,\n  \"itemList\":[\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"sv\":\"ARK-DS520\",\n        \"sensorId\":\"/Platform Information/Board name\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"v\":136957,\n        \"sensorId\":\"/DiskInfo/Disk C Total Disk Space\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "GET",
    "url": "/v1/devicectrl/<primary-key>/histdata?<Parameter>",
    "title": "Get Hist Data",
    "name": "GET_API_2",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Retrieve historic data by device Id from a range. The maximum number of values is 10000. The determination is the process time of server.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "amount",
            "description": "<p>Amount</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "order",
            "description": "<p>Order, e.g., asc or desc</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>&beginTs=<beginTs>&endTs=<endTs>&amount=<amount>&order=<order>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"connected\":false,\n  \"total\":4,\n  \"itemList\":[\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:55:055\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:55:055\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:45:045\"\n     },\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:45:045\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "GET",
    "url": "/v1/devicectrl/<primary-key>/statisticdata?<Parameter>",
    "title": "Get Statistic Data",
    "name": "GET_API_3",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Retrieve statistic data by device Id from a range. (Less than 31 days.) The determination is the process time of server.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>&beginTs=<beginTs>&endTs=<endTs>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"unit\":\"Day\",\n  \"itemList\":[\n     {\n        \"val\":\"250\",\n        \"unit\":\"2017-03-06\",\n        \"count\":\"10\"\n     },\n     {\n        \"val\":\"250\",\n        \"unit\":\"2017-03-07\",\n        \"count\":\"9\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "GET",
    "url": "/v1/devicectrl/<primary-key>/latestdata_by_opts?<Parameter>",
    "title": "Get Latest Data(op)",
    "name": "GET_API_4",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Retrieve lastest data by device Id. The determination is the operation time of agent.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"connected\":false,\n  \"itemList\":[\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"sv\":\"ARK-DS520\",\n        \"sensorId\":\"/Platform Information/Board name\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     },\n     {\n        \"v\":136957,\n        \"sensorId\":\"/DiskInfo/Disk C Total Disk Space\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"Tue Mar 07 18:15:55 CST 2017\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "GET",
    "url": "/v1/devicectrl/<primary-key>/histdata_by_opts?<Parameter>",
    "title": "Get Hist Data(op)",
    "name": "GET_API_5",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Retrieve historic data by device Id from a range. The maximum number of values is 10000. The determination is the operation time of agent.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "amount",
            "description": "<p>Amount</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "order",
            "description": "<p>Order, e.g., asc or desc</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>&beginTs=<beginTs>&endTs=<endTs>&amount=<amount>&order=<order>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"connected\":false,\n  \"total\":4,\n  \"itemList\":[\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:55:055\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:55:055\"\n     },\n     {\n        \"v\":250,\n        \"sensorId\":\"/Backlight/Backlight 1/Brightness\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:45:045\"\n     },\n     {\n        \"sv\":\"1.0.14207\",\n        \"sensorId\":\"/SUSIIoT Information/version\",\n        \"opTS\": \"Fri Apr 14 05:32:39 CST 2017\",\n        \"ts\":\"2017-03-07 10:15:45:045\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "GET",
    "url": "/v1/devicectrl/<primary-key>/statisticdata_by_opts?<Parameter>",
    "title": "Get Statistic Data(op)",
    "name": "GET_API_6",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Retrieve statistic data by device Id from a range. (Less than 31 days.) The determination is the operation time of agent.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-31 00:00:00:000</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>&beginTs=<beginTs>&endTs=<endTs>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"unit\":\"Day\",\n  \"itemList\":[\n     {\n        \"val\":\"250\",\n        \"unit\":\"2017-03-06\",\n        \"count\":\"10\"\n     },\n     {\n        \"val\":\"250\",\n        \"unit\":\"2017-03-07\",\n        \"count\":\"9\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devicetrl/<primary-key>/data?<Parameter>",
    "title": "Get Real-time Data",
    "name": "GET_API_7",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Retrieve real-time data by device Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id, e.g., /SUSIIoT Information/version|/Backlight/Backlight 1/Brightness</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&sensorId=<sensorId>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"sensorIds\":[\n     {\n        \"v\":\"60\",\n        \"sensorId\":\"SUSIControl/Backlight/Backlight 1/Brightness\",\n        \"statusCode\":\"200\",\n        \"ts\":\"2017-04-14 01:17:28:028\"\n     },\n     {\n        \"v\":\"1.0.13644\",\n        \"sensorId\":\"SUSIControl/SUSIIoT Information/version\",\n        \"statusCode\":\"200\",\n        \"ts\":\"2017-04-14 01:17:28:028\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devicetrl/<primary-key>/capability",
    "title": "Get Capability",
    "name": "GET_API_8",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Retrieve capability by device Id.</p>",
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"SUSIControl\":{\n     \"opTS\":{\n        \"$date\":1493270348649\n     },\n     \"SUSIIoT Information\":{\n        \"bt\":1276020076,\n        \"ver\":1,\n        \"bu\":\"Info\",\n        \"e\":[\n           {\n              \"sv\":\"1.0.13916\",\n              \"asm\":\"r\",\n              \"id\":257,\n              \"n\":\"version\"\n           }\n        ],\n        \"id\":256,\n        \"bn\":\"SUSIIoT Information\"\n     },\n     \"Backlight\":{\n        \"Backlight 1\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":1,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":65535,\n                 \"v\":234,\n                 \"asm\":\"rw\",\n                 \"id\":17105409,\n                 \"n\":\"frequency\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":0,\n                 \"asm\":\"rw\",\n                 \"id\":17105665,\n                 \"n\":\"polarity\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":0,\n                 \"asm\":\"rw\",\n                 \"id\":17105921,\n                 \"n\":\"backlight\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":255,\n                 \"v\":250,\n                 \"asm\":\"rw\",\n                 \"id\":17106177,\n                 \"n\":\"brightness\"\n              }\n           ],\n           \"id\":17105153,\n           \"bn\":\"Backlight 1\"\n        },\n        \"id\":327680,\n        \"bn\":\"Backlight\"\n     },\n     \"Platform Information\":{\n        \"ver\":1,\n        \"bt\":1276020076,\n        \"bu\":\"Info\",\n        \"e\":[\n           {\n              \"sv\":\"Advantech\",\n              \"asm\":\"rw\",\n              \"id\":16843777,\n              \"n\":\"Board manufacturer\"\n           },\n           {\n              \"sv\":\"ARK-DS520\",\n              \"id\":16843778,\n              \"n\":\"Board name\"\n           },\n           {\n              \"sv\":\"V1.13\",\n              \"id\":16843781,\n              \"n\":\"BIOS revision\"\n           },\n           {\n              \"sv\":\"4.0.12800\",\n              \"id\":16843265,\n              \"n\":\"Driver version\"\n           },\n           {\n              \"sv\":\"4.0.12800\",\n              \"id\":16843266,\n              \"n\":\"Library version\"\n           }\n        ],\n        \"id\":65536,\n        \"bn\":\"Platform Information\"\n     },\n     \"Hardware Monitor\":{\n        \"Temperature\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"Cel\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":100,\n                 \"v\":69.5,\n                 \"id\":16908545,\n                 \"n\":\"CPU\"\n              },\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":100,\n                 \"v\":0,\n                 \"id\":16908547,\n                 \"n\":\"System\"\n              }\n           ],\n           \"id\":131328,\n           \"bn\":\"Temperature\"\n        },\n        \"Voltage\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":15,\n                 \"v\":1.184,\n                 \"id\":16908801,\n                 \"n\":\"Vcore\"\n              },\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":15,\n                 \"v\":3.408,\n                 \"id\":16908804,\n                 \"n\":\"3.3V\"\n              },\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":15,\n                 \"v\":5.088,\n                 \"id\":16908805,\n                 \"n\":\"5V\"\n              },\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":15,\n                 \"v\":12.288,\n                 \"id\":16908806,\n                 \"n\":\"12V\"\n              },\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":15,\n                 \"v\":5.056,\n                 \"id\":16908807,\n                 \"n\":\"5V Standby\"\n              },\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":15,\n                 \"v\":3.024,\n                 \"id\":16908809,\n                 \"n\":\"CMOS Battery\"\n              }\n           ],\n           \"id\":131584,\n           \"bn\":\"Voltage\"\n        },\n        \"id\":131072,\n        \"Fan Speed\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"RPM\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":8000,\n                 \"v\":0,\n                 \"id\":16909057,\n                 \"n\":\"CPU\"\n              },\n              {\n                 \"min\":0,\n                 \"simMode\":0,\n                 \"max\":8000,\n                 \"v\":10465,\n                 \"id\":16909058,\n                 \"n\":\"System\"\n              }\n           ],\n           \"id\":131840,\n           \"bn\":\"Fan Speed\"\n        },\n        \"bn\":\"Hardware Monitor\"\n     },\n     \"M2Talk\":{\n        \"id\":34603008,\n        \"Device0\":{\n           \"ver\":1,\n           \"bt\":0,\n           \"bu\":\"\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"u\":\"V\",\n                 \"max\":5,\n                 \"v\":0.019608,\n                 \"sui\":\"\",\n                 \"asm\":\"rw\",\n                 \"id\":34603025,\n                 \"n\":\"Brightness\"\n              },\n              {\n                 \"min\":0,\n                 \"uiop\":\"0.0|3.5|0.5\",\n                 \"ui\":\"trackbar\",\n                 \"simMode\":0,\n                 \"u\":\"A\",\n                 \"max\":3.5,\n                 \"v\":1.9,\n                 \"sui\":\"\",\n                 \"asm\":\"rw\",\n                 \"id\":34603026,\n                 \"n\":\"Backlight Current\"\n              },\n              {\n                 \"min\":0,\n                 \"uiop\":\"0|1\",\n                 \"ui\":\"ComboBox\",\n                 \"simMode\":0,\n                 \"u\":\"N/A\",\n                 \"max\":1,\n                 \"v\":0,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603041,\n                 \"n\":\"Button 1\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"CheckBox\",\n                 \"simMode\":0,\n                 \"u\":\"N/A\",\n                 \"max\":1,\n                 \"v\":0,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603042,\n                 \"n\":\"Button 2\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"CheckBox\",\n                 \"simMode\":0,\n                 \"u\":\"N/A\",\n                 \"max\":1,\n                 \"v\":0,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603043,\n                 \"n\":\"Button 3\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"CheckBox\",\n                 \"simMode\":0,\n                 \"u\":\"N/A\",\n                 \"max\":1,\n                 \"v\":0,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603044,\n                 \"n\":\"Button 4\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"Label\",\n                 \"simMode\":0,\n                 \"u\":\"V\",\n                 \"max\":5,\n                 \"v\":0.039216,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603057,\n                 \"n\":\"Proximity\"\n              },\n              {\n                 \"min\":-2,\n                 \"ui\":\"Label\",\n                 \"simMode\":0,\n                 \"u\":\"g\",\n                 \"max\":2,\n                 \"v\":-0.0195,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603073,\n                 \"n\":\"Punch Acc X\"\n              },\n              {\n                 \"min\":-2,\n                 \"ui\":\"Label\",\n                 \"simMode\":0,\n                 \"u\":\"g\",\n                 \"max\":2,\n                 \"v\":-0.0858,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603074,\n                 \"n\":\"Punch Acc Y\"\n              },\n              {\n                 \"min\":-2,\n                 \"ui\":\"Label\",\n                 \"simMode\":0,\n                 \"u\":\"g\",\n                 \"max\":2,\n                 \"v\":0.9984,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603075,\n                 \"n\":\"Punch Acc Z\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"u\":\"g\",\n                 \"max\":16,\n                 \"v\":0.063,\n                 \"sui\":\"\",\n                 \"asm\":\"rw\",\n                 \"id\":34603076,\n                 \"n\":\"Punch Threshold\"\n              },\n              {\n                 \"min\":1,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"u\":\"ms\",\n                 \"max\":1275,\n                 \"v\":35,\n                 \"sui\":\"\",\n                 \"asm\":\"rw\",\n                 \"id\":34603077,\n                 \"n\":\"Punch Time\"\n              },\n              {\n                 \"min\":0.063,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"u\":\"g\",\n                 \"max\":8,\n                 \"v\":0.063,\n                 \"sui\":\"\",\n                 \"asm\":\"rw\",\n                 \"id\":34603089,\n                 \"n\":\"Tap Threshold\"\n              },\n              {\n                 \"min\":1,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"u\":\"ms\",\n                 \"max\":1275,\n                 \"v\":100,\n                 \"sui\":\"\",\n                 \"asm\":\"rw\",\n                 \"id\":34603090,\n                 \"n\":\"Tap Width\"\n              },\n              {\n                 \"min\":1,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"u\":\"ms\",\n                 \"max\":1275,\n                 \"v\":100,\n                 \"sui\":\"\",\n                 \"asm\":\"rw\",\n                 \"id\":34603091,\n                 \"n\":\"Tap Latency\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"CheckBox\",\n                 \"simMode\":0,\n                 \"u\":\"N/A\",\n                 \"max\":1,\n                 \"v\":1,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603105,\n                 \"n\":\"Display 5V\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"CheckBox\",\n                 \"simMode\":0,\n                 \"u\":\"N/A\",\n                 \"max\":1,\n                 \"v\":0,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603106,\n                 \"n\":\"Ext Light\"\n              },\n              {\n                 \"min\":-128,\n                 \"ui\":\"Label\",\n                 \"simMode\":0,\n                 \"u\":\"Cel\",\n                 \"max\":127,\n                 \"v\":39,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603107,\n                 \"n\":\"Temperature\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"Label\",\n                 \"simMode\":0,\n                 \"u\":\"hr\",\n                 \"max\":438000,\n                 \"v\":73,\n                 \"sui\":\"\",\n                 \"asm\":\"r\",\n                 \"id\":34603108,\n                 \"n\":\"Up Time\"\n              }\n           ],\n           \"id\":34603008,\n           \"bn\":\"Device0\"\n        },\n        \"bn\":\"M2Talk\"\n     },\n     \"GPIO\":{\n        \"GPIO02\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17039875,\n                 \"n\":\"Dir\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17040131,\n                 \"n\":\"level\"\n              }\n           ],\n           \"id\":17039619,\n           \"bn\":\"GPIO02\"\n        },\n        \"GPIO01\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17039874,\n                 \"n\":\"Dir\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17040130,\n                 \"n\":\"level\"\n              }\n           ],\n           \"id\":17039618,\n           \"bn\":\"GPIO01\"\n        },\n        \"GPIO04\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17039877,\n                 \"n\":\"Dir\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17040133,\n                 \"n\":\"level\"\n              }\n           ],\n           \"id\":17039621,\n           \"bn\":\"GPIO04\"\n        },\n        \"GPIO03\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17039876,\n                 \"n\":\"Dir\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17040132,\n                 \"n\":\"level\"\n              }\n           ],\n           \"id\":17039620,\n           \"bn\":\"GPIO03\"\n        },\n        \"GPIO06\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17039879,\n                 \"n\":\"Dir\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17040135,\n                 \"n\":\"level\"\n              }\n           ],\n           \"id\":17039623,\n           \"bn\":\"GPIO06\"\n        },\n        \"GPIO05\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17039878,\n                 \"n\":\"Dir\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17040134,\n                 \"n\":\"level\"\n              }\n           ],\n           \"id\":17039622,\n           \"bn\":\"GPIO05\"\n        },\n        \"GPIO07\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17039880,\n                 \"n\":\"Dir\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17040136,\n                 \"n\":\"level\"\n              }\n           ],\n           \"id\":17039624,\n           \"bn\":\"GPIO07\"\n        },\n        \"id\":262144,\n        \"bn\":\"GPIO\",\n        \"GPIO00\":{\n           \"ver\":1,\n           \"bt\":1276020076,\n           \"bu\":\"V\",\n           \"e\":[\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17039873,\n                 \"n\":\"Dir\"\n              },\n              {\n                 \"min\":0,\n                 \"ui\":\"TextBox\",\n                 \"simMode\":0,\n                 \"max\":1,\n                 \"v\":1,\n                 \"asm\":\"rw\",\n                 \"id\":17040129,\n                 \"n\":\"level\"\n              }\n           ],\n           \"id\":17039617,\n           \"bn\":\"GPIO00\"\n        }\n     }\n  },\n  \"NetMonitor\":{\n     \"netMonInfoList\":[\n        {\n           \"bt\":1493270004,\n           \"ver\":1,\n           \"bu\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"VMware Network Adapter VMnet8\",\n                 \"n\":\"adapterName\"\n              },\n              {\n                 \"sv\":\"VMware Virtual Ethernet Adapter for VMnet8\",\n                 \"n\":\"adapterDescription\"\n              },\n              {\n                 \"sv\":\"Ethernet\",\n                 \"n\":\"type\"\n              },\n              {\n                 \"sv\":\"Connected\",\n                 \"n\":\"netStatus\"\n              },\n              {\n                 \"v\":100,\n                 \"n\":\"Link SpeedMbps\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"netUsage\"\n              },\n              {\n                 \"v\":5,\n                 \"n\":\"sendDataByte\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"sendThroughput\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"recvDataByte\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"recvThroughput\"\n              }\n           ],\n           \"bn\":\"Index0-VMware Network Adapter VMnet8\"\n        },\n        {\n           \"bt\":1493270004,\n           \"ver\":1,\n           \"bu\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"VMware Network Adapter VMnet1\",\n                 \"n\":\"adapterName\"\n              },\n              {\n                 \"sv\":\"VMware Virtual Ethernet Adapter for VMnet1\",\n                 \"n\":\"adapterDescription\"\n              },\n              {\n                 \"sv\":\"Ethernet\",\n                 \"n\":\"type\"\n              },\n              {\n                 \"sv\":\"Connected\",\n                 \"n\":\"netStatus\"\n              },\n              {\n                 \"v\":100,\n                 \"n\":\"Link SpeedMbps\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"netUsage\"\n              },\n              {\n                 \"v\":12,\n                 \"n\":\"sendDataByte\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"sendThroughput\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"recvDataByte\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"recvThroughput\"\n              }\n           ],\n           \"bn\":\"Index1-VMware Network Adapter VMnet1\"\n        },\n        {\n           \"bt\":1493270004,\n           \"ver\":1,\n           \"bu\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"Adapter\",\n                 \"n\":\"adapterName\"\n              },\n              {\n                 \"sv\":\"Intel(R) Ethernet Connection I217-LM\",\n                 \"n\":\"adapterDescription\"\n              },\n              {\n                 \"sv\":\"Ethernet\",\n                 \"n\":\"type\"\n              },\n              {\n                 \"sv\":\"Connected\",\n                 \"n\":\"netStatus\"\n              },\n              {\n                 \"v\":1000,\n                 \"n\":\"Link SpeedMbps\"\n              },\n              {\n                 \"v\":0.067958,\n                 \"n\":\"netUsage\"\n              },\n              {\n                 \"v\":99129,\n                 \"n\":\"sendDataByte\"\n              },\n              {\n                 \"v\":0.003046,\n                 \"n\":\"sendThroughput\"\n              },\n              {\n                 \"v\":1586272,\n                 \"n\":\"recvDataByte\"\n              },\n              {\n                 \"v\":0.064913,\n                 \"n\":\"recvThroughput\"\n              }\n           ],\n           \"bn\":\"Index2-Adapter\"\n        },\n        {\n           \"bt\":1493270004,\n           \"ver\":1,\n           \"bu\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"VIA Connection\",\n                 \"n\":\"adapterName\"\n              },\n              {\n                 \"sv\":\"Aruba Virtual Adapter\",\n                 \"n\":\"adapterDescription\"\n              },\n              {\n                 \"sv\":\"Ethernet\",\n                 \"n\":\"type\"\n              },\n              {\n                 \"sv\":\"Disconnect\",\n                 \"n\":\"netStatus\"\n              },\n              {\n                 \"v\":10,\n                 \"n\":\"Link SpeedMbps\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"netUsage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"sendDataByte\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"sendThroughput\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"recvDataByte\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"recvThroughput\"\n              }\n           ],\n           \"bn\":\"Index3-VIA Connection\"\n        }\n     ],\n     \"opTS\":{\n        \"$date\":1493270004550\n     }\n  },\n  \"ProcessMonitor\":{\n     \"Process Monitor Info\":[\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"conhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":14556,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":7704,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":65984,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"14556-conhost.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"CAgent.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":2588,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":17204,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":113708,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"2588-CAgent.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProcessInfoHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10052,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":172,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":21524,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10052-ProcessInfoHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"chrome.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":6364,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":64112,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":145732,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"6364-chrome.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProcessInfoHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7352,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":172,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":21524,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7352-ProcessInfoHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProcessInfoHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":11236,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":168,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":21524,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"11236-ProcessInfoHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProcessInfoHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":13560,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":168,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":21524,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"13560-ProcessInfoHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"conhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9056,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9056-conhost.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"java.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":6336,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"6336-java.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"conhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":15020,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"15020-conhost.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"java.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":13304,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"13304-java.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProcessInfoHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":11648,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"11648-ProcessInfoHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"QQExternal.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":12776,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"12776-QQExternal.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProcessInfoHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":5392,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"5392-ProcessInfoHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"netbeans64.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9940,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9940-netbeans64.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"pgAdmin3.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":14592,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"14592-pgAdmin3.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProcessInfoHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10200,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10200-ProcessInfoHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProcessInfoHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10244,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10244-ProcessInfoHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"devenv.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7236,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7236-devenv.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"mspdbsrv.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":15096,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"15096-mspdbsrv.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"node.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10988,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10988-node.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"conhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":13032,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"13032-conhost.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"cmd.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7308,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7308-cmd.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"TGitCache.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":13336,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"13336-TGitCache.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProcessInfoHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":6452,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"6452-ProcessInfoHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"notepad++.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10280,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10280-notepad++.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"explorer.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7856,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7856-explorer.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"LINE.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":13468,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"13468-LINE.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"firefox.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":13100,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"13100-firefox.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"taskmgr.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8388,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8388-taskmgr.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"tadb.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":12748,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"12748-tadb.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"AndroidServer.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":12640,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"12640-AndroidServer.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"wuauclt.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":13128,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"13128-wuauclt.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"OUTLOOK.EXE\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":11136,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"11136-OUTLOOK.EXE\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"conhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":12228,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"12228-conhost.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"cmd.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":12928,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"12928-cmd.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"chrome.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":12136,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"12136-chrome.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"chrome.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":12084,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"12084-chrome.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"chrome.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":12048,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"12048-chrome.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"chrome.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":11296,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"11296-chrome.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"chrome.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":11192,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"11192-chrome.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"chrome.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8112,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8112-chrome.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"chrome.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9044,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9044-chrome.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"mms.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9736,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9736-mms.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"mms.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":1384,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"1384-mms.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"mms.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9760,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9760-mms.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"mms.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10068,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10068-mms.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"mmsloader.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7116,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7116-mmsloader.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"flux.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10584,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10584-flux.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"AdobeARM.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10520,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10520-AdobeARM.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"PrivacyIconClient.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10324,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10324-PrivacyIconClient.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"YNoteCefRender.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10704,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10704-YNoteCefRender.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"YNoteCefRender.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7804,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7804-YNoteCefRender.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"YNoteCefRender.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10276,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10276-YNoteCefRender.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"IAStorIcon.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10336,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10336-IAStorIcon.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"TXPlatform.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9572,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9572-TXPlatform.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"QQ.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":10152,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"10152-QQ.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"YoudaoNote.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9556,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9556-YoudaoNote.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"jusched.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8740,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8740-jusched.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"mobsync.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9096,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9096-mobsync.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ProductUpdater.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8764,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8764-ProductUpdater.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"acrotray.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8720,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8720-acrotray.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"vmware-tray.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8444,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8444-vmware-tray.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"PccNTMon.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9088,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9088-PccNTMon.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"iusb3mon.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":9016,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"9016-iusb3mon.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ApacheMonitor.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8920,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8920-ApacheMonitor.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"WebCompanion.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8656,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8656-WebCompanion.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"volumouse32.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8456,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8456-volumouse32.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"volumouse.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":1132,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"1132-volumouse.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"FreeAlarmClock.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":5372,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"5372-FreeAlarmClock.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"MiPhoneHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":1796,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"1796-MiPhoneHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"TSVNCache.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7956,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7956-TSVNCache.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"StikyNot.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8184,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8184-StikyNot.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"iTunesHelper.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":8176,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"8176-iTunesHelper.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"Everything.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7996,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7996-Everything.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"RtkNGUI64.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7628,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7628-RtkNGUI64.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"igfxpers.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7648,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7648-igfxpers.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"hkcmd.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7400,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7400-hkcmd.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"igfxsrvc.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7516,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7516-igfxsrvc.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"explorer.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7416,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7416-explorer.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"dwm.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":7368,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"7368-dwm.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ggdllhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":1136,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"1136-ggdllhost.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"ggdllhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":5912,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"5912-ggdllhost.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"taskeng.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":5752,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"5752-taskeng.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"taskhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":4636,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Zach.Chih\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":false,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"4636-taskhost.exe\"\n        }\n     ],\n     \"opTS\":{\n        \"$date\":1493270347693\n     },\n     \"System Monitor Info\":{\n        \"bextend\":\"\",\n        \"bst\":\"\",\n        \"e\":[\n           {\n              \"v\":0,\n              \"n\":\"CPU Usage\"\n           },\n           {\n              \"v\":8258604,\n              \"n\":\"totalPhysMemKB\"\n           },\n           {\n              \"v\":1226552,\n              \"n\":\"availPhysMemKB\"\n           }\n        ],\n        \"basm\":\"R\",\n        \"btype\":\"d\",\n        \"bn\":\"System Monitor Info\"\n     }\n  },\n  \"HDDMonitor\":{\n     \"hddInfoList\":[\n        {\n           \"e\":[\n              {\n                 \"sv\":\"WDC WD10EZEX-22BN5A0\",\n                 \"asm\":\"r\",\n                 \"n\":\"hddName\"\n              },\n              {\n                 \"v\":0,\n                 \"asm\":\"r\",\n                 \"n\":\"hddIndex\"\n              },\n              {\n                 \"u\":\"hour\",\n                 \"v\":12618,\n                 \"asm\":\"r\",\n                 \"n\":\"powerOnTime\"\n              },\n              {\n                 \"u\":\"percent\",\n                 \"v\":18,\n                 \"asm\":\"r\",\n                 \"n\":\"health\"\n              },\n              {\n                 \"sv\":\"STDDisk\",\n                 \"asm\":\"r\",\n                 \"n\":\"hddType\"\n              },\n              {\n                 \"u\":\"celsius\",\n                 \"v\":38,\n                 \"asm\":\"r\",\n                 \"n\":\"hddTemp\"\n              }\n           ],\n           \"bn\":\"Disk0\"\n        }\n     ],\n     \"hddSmartInfoList\":[\n        {\n           \"Temperature\":{\n              \"e\":[\n                 {\n                    \"v\":194,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":8704,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":96,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":105,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000026\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"Temperature\"\n           },\n           \"SeekErrorRate\":{\n              \"e\":[\n                 {\n                    \"v\":7,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":11776,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000000\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"SeekErrorRate\"\n           },\n           \"BaseInfo\":{\n              \"e\":[\n                 {\n                    \"sv\":\"STDDisk\",\n                    \"asm\":\"r\",\n                    \"n\":\"hddType\"\n                 },\n                 {\n                    \"sv\":\"WDC WD10EZEX-22BN5A0\",\n                    \"asm\":\"r\",\n                    \"n\":\"hddName\"\n                 },\n                 {\n                    \"v\":0,\n                    \"asm\":\"r\",\n                    \"n\":\"hddIndex\"\n                 }\n              ],\n              \"bn\":\"BaseInfo\"\n           },\n           \"ReadErrorRate\":{\n              \"e\":[\n                 {\n                    \"v\":1,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":512,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":0,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":0,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000000\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"ReadErrorRate\"\n           },\n           \"bn\":\"Disk0\",\n           \"ReallocatedSectorsCount\":{\n              \"e\":[\n                 {\n                    \"v\":5,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":0,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":0,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":0,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000000\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"ReallocatedSectorsCount\"\n           },\n           \"SpinUpTime\":{\n              \"e\":[\n                 {\n                    \"v\":3,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":9984,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":172,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":175,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"0000000008CA\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"SpinUpTime\"\n           },\n           \"StartStopCount\":{\n              \"e\":[\n                 {\n                    \"v\":4,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":100,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":100,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"0000000003C1\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"StartStopCount\"\n           },\n           \"PowerOnHoursPOH\":{\n              \"e\":[\n                 {\n                    \"v\":9,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":83,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":83,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"00000000314A\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"PowerOnHoursPOH\"\n           },\n           \"UltraDMACRCErrorCount\":{\n              \"e\":[\n                 {\n                    \"v\":199,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000000\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"UltraDMACRCErrorCount\"\n           },\n           \"ReallocationEventCount\":{\n              \"e\":[\n                 {\n                    \"v\":196,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000000\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"ReallocationEventCount\"\n           },\n           \"UncorrectableSectorCount\":{\n              \"e\":[\n                 {\n                    \"v\":198,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12288,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000059\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"UncorrectableSectorCount\"\n           },\n           \"Unknown\":{\n              \"e\":[\n                 {\n                    \"v\":132,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":168,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":1,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":42,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"02000100037B\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"Unknown\"\n           },\n           \"MultiZoneErrorRate\":{\n              \"e\":[\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":2048,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000064\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"MultiZoneErrorRate\"\n           },\n           \"SpinRetryCount\":{\n              \"e\":[\n                 {\n                    \"v\":10,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":100,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":100,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000000\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"SpinRetryCount\"\n           },\n           \"CurrentPendingSectorCount\":{\n              \"e\":[\n                 {\n                    \"v\":197,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"00000000006A\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"CurrentPendingSectorCount\"\n           },\n           \"PowerCycleCount\":{\n              \"e\":[\n                 {\n                    \"v\":12,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":100,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":100,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"0000000003BF\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"PowerCycleCount\"\n           },\n           \"CalibrationRetryCount\":{\n              \"e\":[\n                 {\n                    \"v\":11,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":100,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":100,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000000\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"CalibrationRetryCount\"\n           },\n           \"LoadCycleCount\":{\n              \"e\":[\n                 {\n                    \"v\":193,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"000000000542\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"LoadCycleCount\"\n           },\n           \"PoweroffRetractCount\":{\n              \"e\":[\n                 {\n                    \"v\":192,\n                    \"asm\":\"r\",\n                    \"n\":\"type\"\n                 },\n                 {\n                    \"v\":12800,\n                    \"asm\":\"r\",\n                    \"n\":\"flags\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"worst\"\n                 },\n                 {\n                    \"v\":200,\n                    \"asm\":\"r\",\n                    \"n\":\"value\"\n                 },\n                 {\n                    \"sv\":\"00000000001A\",\n                    \"asm\":\"r\",\n                    \"n\":\"vendorData\"\n                 }\n              ],\n              \"bn\":\"PoweroffRetractCount\"\n           }\n        }\n     ],\n     \"opTS\":{\n        \"$date\":1493270913596\n     }\n  }\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/devicectrl/data",
    "title": "Set Data",
    "name": "POST_API_1",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Set data on device.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "Body Content",
            "type": "String",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "Body Content",
            "type": "String",
            "optional": false,
            "field": "sensorId",
            "description": "<p>Sensor Id</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"item\":{\n     \"agentId\":\"00000001-0000-0000-0000-000BAB578433\",\n     \"plugin\":\"SUSIControl\",\n     \"sensorId\":{\n        \"n\":\"/Hardware Monitor/Voltage/12V\",\n        \"v\":12\n     }\n  }\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"item\":{\n     \"v\":\"Read Only\",\n     \"sensorId\":\"SUSIControl/Hardware Monitor/Voltage/12V\",\n     \"statusCode\":\"405\",\n     \"ts\":\"2017-04-14 01:18:56:056\"\n  }\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/devicectrl/intermittent_report",
    "title": "Intermittent Report",
    "name": "POST_API_2",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Intermittent report of a specific plugin on device.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "Body Content",
            "type": "String",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "requestItems",
            "description": "<p>Request Items. If not provided, default report all data.</p>"
          },
          {
            "group": "Body Content",
            "type": "String",
            "optional": false,
            "field": "interval",
            "description": "<p>Interval (sec)</p>"
          },
          {
            "group": "Body Content",
            "type": "String",
            "optional": false,
            "field": "timeout",
            "description": "<p>Timeout (sec)</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"agentid\":\"00000001-0000-0000-0000-305A3A77B1DA\",\n  \"plugin\":\"SUSIControl\",\n  \"requestItems\":{\n     \"e\":[\n        {\n           \"n\":\"SUSIControl/Hardware Monitor/Temperature\"\n        },\n        {\n           \"n\":\"SUSIControl/Hardware Monitor/Voltage/12V\"\n        }\n     ]\n  },\n  \"interval\":1,\n  \"timeout\":30\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/devicectrl/periodic_report",
    "title": "Periodic Report",
    "name": "POST_API_3",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Periodic report of device.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "requestItems",
            "description": "<p>Request Items. If not provided, default report all data.</p>"
          },
          {
            "group": "Body Content",
            "type": "String",
            "optional": false,
            "field": "interval",
            "description": "<p>Interval (sec)</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"agentid\":\"00000001-0000-0000-0000-000BAB578433\",\n  \"requestItems\":{\n     \"SUSIControl\":{\n        \"e\":[\n           {\n              \"n\":\"SUSIControl/Backlight\"\n           },\n           {\n              \"n\":\"SUSIControl/Hardware Monitor/Voltage/12V\"\n           }\n        ]\n     },\n     \"HDDMonitor\":{\n        \"e\":[\n           {\n              \"n\":\"HDDMonitor/hddInfoList/Disk0-ST250LT012-9WS141/hddType\"\n           }\n        ]\n     }\n  },\n  \"interval\":1\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/devicectrl/report_suspension",
    "title": "Suspend Report",
    "name": "POST_API_4",
    "group": "devicectrl",
    "version": "1.0.0",
    "description": "<p>Suspend periodic report of device.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"agentid\":\"00000001-0000-0000-0000-000BAB578433\",\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/DeviceCtrlAPIDOC.java",
    "groupTitle": "devicectrl"
  },
  {
    "type": "Delete",
    "url": "/rmm/v1/devicegroups/<primary-key>",
    "title": "Delete DeviceGroup",
    "name": "DELETE_API_1",
    "group": "devicegroups",
    "version": "1.0.0",
    "description": "<p>Delete a specific device group by group Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>group Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devicegroups"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devicegroups",
    "title": "Get DeviceGroups",
    "name": "GET_API_1",
    "group": "devicegroups",
    "version": "1.0.0",
    "description": "<p>Retrieve all device group information.</p>",
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"devicegroups\":[\n     {\n        \"gid\":1,\n        \"name\":\"Advantech-33F\",\n        \"description\":\"Group of Advantech 33F\",\n        \"createTS\":\"2017-04-27 13:30:03.945\",\n        \"aid\":1\n     },\n     {\n        \"gid\":2,\n        \"name\":\"Advantech-44F\",\n        \"description\":\"Group of Advantech 44F\",\n        \"createTS\":\"2017-04-27 13:30:03.955\",\n        \"parentGroup\":{\n           \"gid\":1,\n           \"name\":\"Advantech-33F\"\n        },\n        \"aid\":1\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devicegroups"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devicegroups/<primary-key>",
    "title": "Get DeviceGroup",
    "name": "GET_API_2",
    "group": "devicegroups",
    "version": "1.0.0",
    "description": "<p>Retrieve a specific device group information by group Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>device group Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"devicegroups\":[\n     {\n        \"gid\":2,\n        \"name\":\"Advantech-44F\",\n        \"description\":\"Group of Advantech 44F\",\n        \"createTS\":\"2017-04-27 13:30:03.955\",\n        \"parentGroup\":{\n           \"gid\":1,\n           \"name\":\"Advantech-33F\"\n        },\n        \"aid\":1\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devicegroups"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devicegroups/<primary-key>/devices?<Parameter>",
    "title": "Get Devices/DeviceGroup",
    "name": "GET_API_3",
    "group": "devicegroups",
    "version": "1.0.0",
    "description": "<p>Retrieve device information by group Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>device group Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "pageSize",
            "description": "<p>Page Size</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "no",
            "description": "<p>Page Number</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "orderType",
            "description": "<p>Order Type</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "orderBy",
            "description": "<p>Order By</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "like",
            "description": "<p>Like Parameter</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "pageSize=<pageSize>&no=<no>&orderType=<orderType>&orderBy=<orderBy>&like=<like>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample (json)",
          "content": "{\n  \"groups\":[\n     {\n        \"gid\":2,\n        \"devices\":[\n           {\n              \"agentid\":\"00000001-0000-0000-0000-000babbb7ef3\",\n              \"product\":\"\",\n              \"coordinates\":\"25.037531,121.5639969\",\n              \"version\":\"1\",\n              \"mac\":\"1\",\n              \"parentid\":\"00000001-0000-0000-0000-000babbb7ef4\",\n              \"manufacturer\":\"\",\n              \"logints\":\"2017-02-23 16:18:44.447\",\n              \"connected\":true,\n              \"name\":\"ARK-DS520\",\n              \"createts\":\"2017-02-23 16:18:44.447\",\n              \"sn\":\"\",\n              \"tag\":\"1\",\n              \"did\":1\n           },\n           {\n              \"agentid\":\"00000005-0000-0000-000a-rkksa0451097\",\n              \"product\":\"\",\n              \"coordinates\":\"25.037531,121.5639969\",\n              \"version\":\"2\",\n              \"mac\":\"2\",\n              \"parentid\":\"\",\n              \"manufacturer\":\"\",\n              \"logints\":\"2017-02-23 16:18:44.453\",\n              \"connected\":false,\n              \"name\":\"WISE-1520\",\n              \"createts\":\"2017-02-23 16:18:44.453\",\n              \"sn\":\"\",\n              \"tag\":\"2\",\n              \"did\":2\n           }\n        ],\n        \"name\":\"Advantech-2F\",\n        \"description\":\"Group of Advantech 2F\",\n        \"createts\":\"2017-02-21 14:30:15.038\",\n        \"aid\":2\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devicegroups"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/devicegroups",
    "title": "Add DeviceGroups",
    "name": "POST_API_1",
    "group": "devicegroups",
    "version": "1.0.0",
    "description": "<p>Add device group information.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "name",
            "description": "<p>Device group name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "description",
            "description": "<p>Device group description</p>"
          },
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "aid",
            "description": "<p>Account Id</p>"
          },
          {
            "group": "Body Content",
            "type": "long",
            "optional": true,
            "field": "parentGid",
            "description": "<p>Parent group Id</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"devicegroups\":[\n     {\n        \"name\":\"Advantech-1F\",\n        \"description\":\"Group of Advantech 1F\",\n        \"aid\":1,\n        \"parentGid\":1\n     },\n     {\n        \"name\":\"Advantech-2F\",\n        \"description\":\"Group of Advantech 2F\",\n        \"aid\":\"1\",\n        \"parentGid\":1\n     }\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devicegroups"
  },
  {
    "type": "Put",
    "url": "/rmm/v1/devicegroups",
    "title": "Edit DeviceGroups",
    "name": "PUT_API_1",
    "group": "devicegroups",
    "version": "1.0.0",
    "description": "<p>Edit device group information.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "gid",
            "description": "<p>Device group Id</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "name",
            "description": "<p>Device group name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "description",
            "description": "<p>Device group description</p>"
          },
          {
            "group": "Body Content",
            "type": "long",
            "optional": true,
            "field": "aid",
            "description": "<p>Account Id</p>"
          },
          {
            "group": "Body Content",
            "type": "long",
            "optional": true,
            "field": "parentGid",
            "description": "<p>Parent group Id</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"devicegroups\":[\n     {\n        \"gid\":3,\n        \"name\":\"Advantech-5F\",\n        \"description\":\"Group of Advantech 5F\",\n        \"aid\":1,\n        \"parentGid\":5\n     },\n     {\n        \"gid\":4,\n        \"name\":\"Advantech-6F\",\n        \"description\":\"Group of Advantech 6F\",\n        \"aid\":1\n     }\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devicegroups"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devices",
    "title": "Get Devices",
    "name": "GET_API_1",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve all device information.</p>",
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"devices\":[\n     {\n        \"connected\":true,\n        \"agentId\":\"00000001-0000-0000-0000-000BAB578433\",\n        \"name\":\"ARK-2150-PC\",\n        \"coordinates\":\"\",\n        \"devicegroups\":[\n           {\n              \"gid\":1,\n              \"name\":\"Advantech-1F\",\n              \"description\":\"Group of Advantech 1F\",\n              \"createTS\":\"2017-04-07 16:53:00.858\",\n              \"aid\":1\n           },\n           {\n              \"gid\":2,\n              \"name\":\"Advantech-2F\",\n              \"description\":\"Group of Advantech 2F\",\n              \"createTS\":\"2017-04-07 16:53:00.862\",\n              \"aid\":1,\n              \"parentGid\":3\n           },\n           {\n              \"gid\":4,\n              \"name\":\"Advantech-4F\",\n              \"description\":\"Group of Advantech 4F\",\n              \"createTS\":\"2017-04-07 16:53:00.858\",\n              \"aid\":1,\n              \"parentGid\":5\n           }\n        ],\n        \"createTS\":\"2017-04-24 17:28:04.007\",\n        \"did\":5,\n        \"parentId\":\"\",\n        \"loginTS\":\"2017-04-24 17:28:04.007\"\n     },\n     {\n        \"connected\":false,\n        \"agentId\":\"00000001-0000-0000-0000-366A3A700000\",\n        \"name\":\"PC001104\",\n        \"coordinates\":\"\",\n        \"devicegroups\":[\n           {\n              \"gid\":1,\n              \"name\":\"Advantech-1F\",\n              \"description\":\"Group of Advantech 1F\",\n              \"createTS\":\"2017-04-07 16:53:00.858\",\n              \"aid\":1\n           }\n        ],\n        \"createTS\":\"2017-04-10 10:38:17.665\",\n        \"did\":2,\n        \"parentId\":\"\",\n        \"loginTS\":\"2017-04-10 10:38:17.665\"\n     },\n     {\n        \"connected\":false,\n        \"agentId\":\"00000001-0000-0000-0000-305A3A77B1DA\",\n        \"name\":\"PC001104\",\n        \"coordinates\":\"\",\n        \"devicegroups\":[\n\n        ],\n        \"createTS\":\"2017-04-13 15:23:20.723\",\n        \"did\":3,\n        \"parentId\":\"\",\n        \"loginTS\":\"2017-04-13 15:23:20.723\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devices/<primary-key>",
    "title": "Get Device",
    "name": "GET_API_2",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve a specific device information by device Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"devices\":[\n     {\n        \"connected\":true,\n        \"agentId\":\"00000001-0000-0000-0000-000babbb7ef3\",\n        \"name\":\"ARK-DS520\",\n        \"coordinates\":\"25.037531,121.5639969\",\n        \"devicegroups\":[\n           {\n              \"gid\":1,\n              \"name\":\"Advantech-3F\",\n              \"description\":\"Group of Advantech 3F\",\n              \"createTS\":\"2017-02-07 10:15:53.086\",\n              \"aid\":1\n           },\n           {\n              \"gid\":2,\n              \"name\":\"Advantech-4F\",\n              \"description\":\"Group of Advantech 4F\",\n              \"createTS\":\"2017-02-07 10:15:53.091\",\n              \"aid\":1\n           }\n        ],\n        \"createTS\":\"2017-02-07 11:22:33.526\",\n        \"parentId\":\"\",\n        \"did\":1,\n        \"loginTS\":\"2017-02-07 11:22:33.526\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devices/unassigned",
    "title": "Get UnAssigned Devices",
    "name": "GET_API_3",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve unassigned device information.</p>",
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"devices\":[\n     {\n        \"connected\":true,\n        \"agentId\":\"00000001-0000-0000-0000-306A3A700000\",\n        \"name\":\"ARK-DS520\",\n        \"coordinates\":\"25.037531,121.5639969\",\n        \"devicegroups\":[\n\n        ],\n        \"createTS\":\"2017-03-15 13:54:56.049\",\n        \"did\":1,\n        \"loginTS\":\"2017-03-15 13:54:56.049\"\n     },\n     {\n        \"connected\":true,\n        \"agentId\":\"00000001-0000-0000-0000-366A3A700000\",\n        \"name\":\"Zach_366A3A700000\",\n        \"coordinates\":\"\",\n        \"devicegroups\":[\n\n        ],\n        \"createTS\":\"2017-03-15 14:29:57.273\",\n        \"did\":2,\n        \"loginTS\":\"2017-03-15 14:29:57.273\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devices/<primary-key>/plugins_within_timerange?<Parameter>",
    "title": "Get Plugins/Device within a time range",
    "name": "GET_API_4",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve plugins by device Id within a time range. The maximum amount of data to determine plugins is 10000.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-30 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "amount",
            "description": "<p>Amount</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "order",
            "description": "<p>Order</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&beginTs=<beginTs>&endTs=<endTs>&amount=<amount>&order=<order>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"total\":4,\n  \"plugins\":[\n     {\n        \"plugin\":\"ProcessMonitor\"\n     },\n     {\n        \"plugin\":\"NetMonitor\"\n     },\n     {\n        \"plugin\":\"SUSIControl\"\n     },\n     {\n        \"plugin\":\"HDDMonitor\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devices/<primary-key>/plugins",
    "title": "Get Plugins/Device",
    "name": "GET_API_5",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve plugins by device Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"total\":4,\n  \"plugins\":[\n     {\n        \"plugin\":\"ProcessMonitor\"\n     },\n     {\n        \"plugin\":\"NetMonitor\"\n     },\n     {\n        \"plugin\":\"SUSIControl\"\n     },\n     {\n        \"plugin\":\"HDDMonitor\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/devices/<primary-key>/sensors?<Parameter>",
    "title": "Get Sensors/Device",
    "name": "GET_API_6",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Retrieve sensors by device Id &amp; plugin within a time range. The maximum number of values is 10000.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "agentId",
            "description": "<p>Agent Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "plugin",
            "description": "<p>Plugin Name</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "beginTs",
            "description": "<p>Begin Timestamp, e.g.,2017-04-06 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "endTs",
            "description": "<p>End Timestamp, e.g.,2017-04-30 00:00:00:000</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "amount",
            "description": "<p>Amount</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "order",
            "description": "<p>Order</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "agentId=<agentId>&plugin=<plugin>&beginTs=<beginTs>&endTs=<endTs>&amount=<amount>&order=<order>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"total\":5,\n  \"sensorIds\":[\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/hddType\"\n     },\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/hddName\"\n     },\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/hddIndex\"\n     },\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/powerOnTime\"\n     },\n     {\n        \"sensorId\":\"/hddInfoList/Disk0-ST250LT012-9WS141/hddHealthPercent\"\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "Put",
    "url": "/rmm/v1/devices",
    "title": "Edit Devices",
    "name": "PUT_API_1",
    "group": "devices",
    "version": "1.0.0",
    "description": "<p>Edit device group information.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "did",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "groupId",
            "description": "<p>Group Id</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"devices\":[\n     {\n        \"did\":3,\n        \"groupIds\":[\n           1,\n           2\n        ]\n     },\n     {\n        \"did\":4,\n        \"groupIds\":[\n           1\n        ]\n     }\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/device/DeviceAPIDoc.java",
    "groupTitle": "devices"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/power/device",
    "title": "Power/Device",
    "name": "POST_API_1",
    "group": "power",
    "version": "1.0.0",
    "description": "<p>Power control on device.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "did",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "Body Content",
            "type": "String",
            "optional": false,
            "field": "action",
            "description": "<p>Action (sleep,hibernate,shutdown,reboot,start)</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"did\":1,\n  \"action\":\"reboot\"\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/PowerAPIDOC.java",
    "groupTitle": "power"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/power/group",
    "title": "Power/Group",
    "name": "POST_API_2",
    "group": "power",
    "version": "1.0.0",
    "description": "<p>Power control on group.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "gid",
            "description": "<p>Group Id</p>"
          },
          {
            "group": "Body Content",
            "type": "String",
            "optional": false,
            "field": "action",
            "description": "<p>Action (sleep,hibernate,shutdown,reboot,start)</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"gid\":1,\n  \"action\":\"reboot\"\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/PowerAPIDOC.java",
    "groupTitle": "power"
  },
  {
    "type": "Get",
    "url": "/rmm/v1/processes/devices/<primary-key>",
    "title": "Get Process",
    "name": "GET_API_1",
    "group": "process",
    "version": "1.0.0",
    "description": "<p>Get all process information.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Device Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"ProcessMonitor\":{\n     \"handler\":\"ProcessMonitor\",\n     \"agentId\":\"00000001-0000-0000-0000-000BAB578433\",\n     \"Process Monitor Info\":[\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"CAgent.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":4868,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":2,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":18200,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":149808,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"4868-CAgent.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"conhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":4328,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":5644,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":65776,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"4328-conhost.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"cmd.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":3652,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":3248,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":51116,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"3652-cmd.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"notepad.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":4888,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":6640,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":62384,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"4888-notepad.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"notepad++.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":4468,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":15764,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":120036,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"4468-notepad++.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"jucheck.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":5112,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":12856,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":158628,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"5112-jucheck.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"PrivacyIconClient.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":4280,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":22724,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":529600,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"4280-PrivacyIconClient.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"TibMounterMonitor.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":3292,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":8496,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":95964,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"3292-TibMounterMonitor.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"jusched.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":1384,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":12964,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":136512,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"1384-jusched.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"iusb3mon.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":2752,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":5548,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":91004,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"2752-iusb3mon.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"flux.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":3640,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":19288,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":147024,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"3640-flux.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"schedhlp.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":3552,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":4632,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":79856,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"3552-schedhlp.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"RAVCpl64.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":1216,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":11208,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":72992,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"1216-RAVCpl64.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"igfxpers.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":1688,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":8016,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":66044,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"1688-igfxpers.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"hkcmd.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":156,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":7072,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":62108,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"156-hkcmd.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"igfxtray.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":3824,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":7256,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":67920,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"3824-igfxtray.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"USBManager.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":3972,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":16200,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":178900,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"3972-USBManager.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"explorer.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":1232,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":54652,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":151796,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"1232-explorer.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"dwm.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":3680,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":58024,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":199344,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"3680-dwm.exe\"\n        },\n        {\n           \"bextend\":\"\",\n           \"bst\":\"\",\n           \"e\":[\n              {\n                 \"sv\":\"taskhost.exe\",\n                 \"n\":\"Name\"\n              },\n              {\n                 \"v\":1560,\n                 \"n\":\"PID\"\n              },\n              {\n                 \"sv\":\"Advantech\",\n                 \"n\":\"Owner\"\n              },\n              {\n                 \"v\":0,\n                 \"n\":\"CPU Usage\"\n              },\n              {\n                 \"v\":7880,\n                 \"n\":\"Mem Usage\"\n              },\n              {\n                 \"v\":69244,\n                 \"n\":\"Virtual Mem Usage\"\n              },\n              {\n                 \"bv\":true,\n                 \"n\":\"IsActive\"\n              }\n           ],\n           \"basm\":\"R\",\n           \"btype\":\"d\",\n           \"bn\":\"1560-taskhost.exe\"\n        }\n     ],\n     \"opTS\":{\n        \"$date\":1492119158982\n     },\n     \"System Monitor Info\":{\n        \"bextend\":\"\",\n        \"bst\":\"\",\n        \"e\":[\n           {\n              \"v\":2,\n              \"n\":\"CPU Usage\"\n           },\n           {\n              \"v\":1974724,\n              \"n\":\"totalPhysMemKB\"\n           },\n           {\n              \"v\":950380,\n              \"n\":\"availPhysMemKB\"\n           }\n        ],\n        \"basm\":\"R\",\n        \"btype\":\"d\",\n        \"bn\":\"System Monitor Info\"\n     },\n     \"_id\":{\n        \"$oid\":\"58eb15d1d527a217584a3d56\"\n     },\n     \"ts\":{\n        \"$date\":1492064758666\n     }\n  }\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/ProcessCtrlAPIDOC.java",
    "groupTitle": "process"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/processes",
    "title": "Ctrl Process",
    "name": "POST_API_1",
    "group": "process",
    "version": "1.0.0",
    "description": "<p>Process control.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "did",
            "description": "<p>Device Id</p>"
          },
          {
            "group": "Body Content",
            "type": "String",
            "optional": false,
            "field": "action",
            "description": "<p>Action, e.g., kill or reset.</p>"
          },
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "pid",
            "description": "<p>Process Id</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"did\":1,\n  \"action\":\"kill\",\n  \"pids\":[\n     2628\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/devctrl/ProcessCtrlAPIDOC.java",
    "groupTitle": "process"
  },
  {
    "type": "delete",
    "url": "/rmm/v1/roles/<Primary-key>",
    "title": "Delete Role",
    "name": "DELETE_API_1",
    "group": "roles",
    "version": "1.0.0",
    "description": "<p>Delete a specific role by role Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Role Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "roles"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/roles?<Parameter>",
    "title": "Get Roles",
    "name": "GET_API_1",
    "group": "roles",
    "version": "1.0.0",
    "description": "<p>Retrieve all role information.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "pageSize",
            "description": "<p>Page Size</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "no",
            "description": "<p>Page Number</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "orderType",
            "description": "<p>Order Type</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "orderBy",
            "description": "<p>Order By</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "like",
            "description": "<p>Like Parameter</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "pageSize=<pageSize>&no=<no>&orderType=<orderType>&orderBy=<orderBy>&like=<like>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"roles\":[\n     {\n        \"name\":\"admin\",\n        \"description\":\"System Administrator\",\n        \"createTS\":\"2017-01-01 00:00:00.000\",\n        \"rid\":1\n     },\n     {\n        \"name\":\"Product Admin\",\n        \"description\":\"Product Administrator\",\n        \"createTS\":\"2017-01-01 00:00:00.000\",\n        \"rid\":2\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "roles"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/roles/<primary-key>",
    "title": "Get Role",
    "name": "GET_API_2",
    "group": "roles",
    "version": "1.0.0",
    "description": "<p>Retrieve a specific role information by role Id.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Role Id</p>"
          }
        ]
      }
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"roles\":[\n     {\n        \"name\":\"Product Admin\",\n        \"description\":\"Product Administrator\",\n        \"createTS\":\"2017-01-01 00:00:00.000\",\n        \"rid\":2\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "roles"
  },
  {
    "type": "GET",
    "url": "/rmm/v1/roles/<primary-key>/accounts?<Parameter>",
    "title": "Get Accounts/Role",
    "name": "GET_API_3",
    "group": "roles",
    "version": "1.0.0",
    "description": "<p>Retrieve a specific role information with account information.</p>",
    "parameter": {
      "fields": {
        "URL Parameter": [
          {
            "group": "URL Parameter",
            "type": "long",
            "optional": false,
            "field": "Primary-key",
            "description": "<p>Role Id</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "pageSize",
            "description": "<p>Page Size</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "no",
            "description": "<p>Page Number</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "orderType",
            "description": "<p>Order Type</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "orderBy",
            "description": "<p>Order By</p>"
          },
          {
            "group": "URL Parameter",
            "type": "string",
            "optional": false,
            "field": "like",
            "description": "<p>Like Parameter</p>"
          }
        ]
      },
      "examples": [
        {
          "title": "URL-Parameter Pattern:",
          "content": "pageSize=<pageSize>&no=<no>&orderType=<orderType>&orderBy=<orderBy>&like=<like>",
          "type": "xml"
        }
      ]
    },
    "success": {
      "examples": [
        {
          "title": "ResponseExample(json)",
          "content": "{\n  \"roles\":[\n     {\n        \"name\":\"admin\",\n        \"description\":\"System Administrator\",\n        \"createTS\":\"2017-01-01 00:00:00.000\",\n        \"accounts\":[\n           {\n              \"firstName\":\"admin\",\n              \"lastName\":\"admin\",\n              \"mail\":\"admin@advantech.com.tw\",\n              \"name\":\"admin\",\n              \"fullName\":\"admin\",\n              \"createTS\":\"2017-01-01 00:00:00.000\",\n              \"rid\":1,\n              \"aid\":1,\n              \"loginTS\":\"2017-01-01 00:00:00.000\"\n           },\n           {\n              \"firstName\":\"fllan\",\n              \"lastName\":\"Chen\",\n              \"mail\":\"allan@advantech.com.tw\",\n              \"name\":\"fllan\",\n              \"fullName\":\"fllan Chen\",\n              \"createTS\":\"2017-03-14 11:19:37.262\",\n              \"rid\":1,\n              \"aid\":3,\n              \"loginTS\":\"2017-03-14 11:19:37.262\"\n           }\n        ],\n        \"rid\":1\n     }\n  ]\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "roles"
  },
  {
    "type": "Post",
    "url": "/rmm/v1/roles",
    "title": "Add Roles",
    "name": "POST_API_1",
    "group": "roles",
    "version": "1.0.0",
    "description": "<p>Add role information.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "string",
            "optional": false,
            "field": "name",
            "description": "<p>Role Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "description",
            "description": "<p>Role Description</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"roles\":[\n     {\n        \"name\":\"NorthAmerica Manager\",\n        \"description\":\"North America Manager\"\n     },\n     {\n        \"name\":\"EastAsia Manager\",\n        \"description\":\"East Asia Manager\"\n     }\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "roles"
  },
  {
    "type": "put",
    "url": "/rmm/v1/roles",
    "title": "Edit Roles",
    "name": "PUT_API_1",
    "group": "roles",
    "version": "1.0.0",
    "description": "<p>Edit a specific role information by role Id.</p>",
    "parameter": {
      "fields": {
        "Body Content": [
          {
            "group": "Body Content",
            "type": "long",
            "optional": false,
            "field": "rid",
            "description": "<p>Role Id</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "name",
            "description": "<p>Role Name</p>"
          },
          {
            "group": "Body Content",
            "type": "string",
            "optional": true,
            "field": "description",
            "description": "<p>Role Description</p>"
          }
        ]
      }
    },
    "examples": [
      {
        "title": "Request Example(json)",
        "content": "{\n  \"roles\":[\n     {\n        \"rid\":3,\n        \"name\":\"NorthAmerica Manager\",\n        \"description\":\"North America Manager\"\n     },\n     {\n        \"rid\":4,\n        \"name\":\"EastAsia Manager\",\n        \"description\":\"East Asia Manager\"\n     }\n  ]\n}",
        "type": "json"
      }
    ],
    "success": {
      "examples": [
        {
          "title": "Response Example(json)",
          "content": "{\n  \"result\":true\n}",
          "type": "json"
        }
      ]
    },
    "filename": "D:/work/RMM-EI-Server/WebApp/src/main/java/com/rest/account/AccountAPIDoc.java",
    "groupTitle": "roles"
  }
] });
